#!/usr/bin/perl

package TRY;

require Exporter;

@ISA = qw(Exporter);

@EXPORT = qw( try catch finally );

sub try (&$ );
sub catch (&;$ );
sub finally (&;$ );

#
#sub failure (&;$ );
#sub success (&;$ );
	   
sub try (&$)
{
    my ($try, $catch) = @_;

    my ($throw, $throwMessage);

    $throw = 0;

    # Run the try block
    eval { &$try () };
    # See if it threw any errors
    if ($@)
    {
	# It did, see if there's a catch block
	if ($catch->{catch})
	{
	    # There is, set $_ to the error message
	    local $error = $@;
	    # Run the catch block
	    eval { $_ = $error; &{$catch->{catch}} };
	    # See if the catch block threw any errors
	    if ($@)
	    {
		# It did, save the error for later use
		$throw = 1;
		$throwMessage = $@;
	    }
	}
	else
	{
	    # No catch block, save the error for later use
	    $throw = 1;
	    $throwMessage = $@;
	}
    }
    # See if there is a finally block
    if ($catch->{finally})
    {
	# There is, evaulate the finally block
	eval { &{$catch->{finally}} };
	# See if it threw any errors
	if ($@)
	{
	    # It did, save the error for later use
	    # This will override anything thrown above that hasn't been
	    # caught.
	    $throw = 1;
	    $throwMessage = $@;
	}
    }
    # See if we caught any unhandled errors above
    if ($throw)
    {
	# We did, re-throw the error.
	die ($throwMessage);
    }
}

sub catch (&;$)
{
    if (scalar (@_) == 1)
    {
	return {catch => $_[0]};
    }
    else
    {
	return mergeHandlers ($_[1], {catch   => $_[0]});
    }
}

sub finally (&;$)
{
    if (scalar (@_) == 1)
    {
	return {finally => $_[0]};
    }
    else
    {
	return mergeHandlers ($_[1], {finally => $_[0]});
    }
}

#sub success (&;$)
#{
#    if (scalar (@_) == 1)
#    {
#	return {success => $_[0]};
#    }
#    else
#    {
#	return mergeHandlers ($_[1], {success => $_[0]});
#    }
#}

sub mergeHandlers ($$)
{
    my (
	$handlers1,
	$handlers2
	) = @_;
    my (
	$newHandler,
	$key
	);
    $newHandler = {};
    $newHandler->{$_} = $handlers1->{$_} foreach keys (%$handlers1);
    foreach $key (keys (%$handlers2))
    {
	if (exists ($newHandler->{$key}))
	{
	    die ("Can't have more than one $key block for 'try'");
	}
	$newHandler->{$key} = $handlers2->{$key};
    }
    return $newHandler;
}

1;
