#!/usr/bin/perl

# Routine to add quotes around unquoted value strings in PDS labels.
#
#  Format: addquotes [ <input> [ <output> ] ]
#
# 29 Jan 2003, acr
#===========================================================================

$TMPFILE   = "__TMPaddquotes";
$OVERWRITE = 0;

# Open the files:

if (@ARGV > 2)
  { die "Usage: addquotes [ <input_file> [ <output_file> ] ]\n"; }

if (@ARGV == 1  &&  $ARGV[0] eq "-h"  ||  $ARGV[0] eq "?")
  { die "Usage: addquotes [ <input_file> [ <output_file> ] ]\n"; }

$infile  = "-";
$outfile = "-";

if (@ARGV > 0)
  { $infile = $ARGV[0]; }

if (@ARGV > 1)
  { $outfile = $ARGV[1]; }

if ($infile ne "-"  &&  $infile eq $outfile)
  { $outfile = $TMPFILE; 
    $OVERWRITE = 1;
  }

open (INP, $infile)      ||  die "Could not open input file ($infile).";
open (OUT, ">$outfile")  ||  die "Could not open output file ($outfile).";

# We step through the lines of the input file, looking for values consisting
# entirely of uppercase letters, numbers and underscores that are not 
# already enclosed in quotes:

$ln = 0;
while ($line=<INP>)
  { $ln++;

    if ($line =~ /^\s*([A-Z_0-9]+)\s*=\s*([A-Z][A-Z_0-9]*)(\s*)$/)
      { $key = $1;
        $val = $2;
        $end = $3;

        # Actual, honest-to-God identifiers shouldn't be touched.
        # Fortunately, these are relatively few:

        if ($key =~ /OBJECT/  ||  $key =~ /GROUP/  ||  
            $key =~ /PDS_VERSION_ID/)
          { printf OUT $line; 
            next;
          }

        # We will try to preserve line padding if possible, so first we'll
        # check to see if there are a couple extra blanks following the 
        # value:

        if ($end =~ /  /)
          { $line =~ s/$val  /"$val"/; }
        elsif (length($line) < 80)
          { $line =~ s/$val/"$val"/; }
        else
          { $line =~ s/$val/"$val"/; 
            $len = length($line);
            printf STDERR "WARNING: line $ln is now > 80 bytes.\n";
          }
      }

    # Print the line and move on:

    printf OUT $line;
  }

close(OUT);
close(IN);

# If we are overwriting the input file, we do it now:

if ($OVERWRITE)
  { rename $TMPFILE, $file; }

# And we're done.
