/*

    Routine to check the contents of a PDS text file for format and content
    at the character level.  Lines must be fixed-length and delimited by
    CR/LF unless otherwise specified, and must contain only valid, 7-bit
    ASCII characters.

    Format:  % checkpdstext [-v] [-l] [ input_file [ output_file ] ]

    20 Apr 1999, acr: creation

*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>

#define  MAXLENGTH  10000       /* Maximum input record length */

main(argc,argv)
  int    argc;
  char  *argv[];

{ int      length;           /* record length of first (should be all) record */
  FILE    *ifp;              /* input file pointer */

  char     line[MAXLENGTH];  /* input line buffer */
  int      i,j,k;            /* loop/subscript */
  int      linelen;          /* input line length */
  int      maxlen,minlen;    /* longest and shortest line lengths */
  int      count;            /* record count */
  int      LF;               /* TRUE if user wants linefeed-only delimiters */
  int      VAR;              /* TRUE if user wants variable-length records */


  count  = 0;
  LF     = 0;                /* Default is CR/LF delimiters */
  ifp    = NULL;


  /* Gather up the input arguments and open the files: */

  if (argc > 4)
    { fprintf (stdout,
               "Usage: checkpdstext [-v] [-l] [ input_file ]\n");
      exit(0);
    }

  i = 1;
  while (i < argc)
    { if (strcmp(argv[i],"-l") == 0)       /* LF only option */
          LF = 1;

      else if (strcmp(argv[i],"-v") == 0)  /* Variable-length record option */
          VAR = 1;

      else if (ifp == NULL)                /* Input file name */
        { if ((ifp = fopen(argv[i],"r")) == NULL)
            { fprintf (stdout,"fixlen: Could not open %s for reading (%s)\n",
                              argv[i],strerror(errno));
              exit(10);
            }
        }

      i++;     /* Next argument */
    }

  /* Use standard I/O if none was specified: */

  if (ifp == NULL) ifp = stdin;

/*---------------------------------------------------------------------------*/
  /* Begin loop through input records:  */

  length = 0;
  maxlen = 0;
  minlen = MAXLENGTH;

  while (fgets(line,MAXLENGTH,ifp) !=NULL) 
    { linelen = strlen(line);
      count++;

      /* Save length of first line: */

      if (count==1) length = linelen;

      /* Check length against extrema: */

      maxlen = (linelen > maxlen)? linelen : maxlen;
      minlen = (linelen < minlen)? linelen : minlen;

      /* Check for varying lengths in fixed-length file: */

      if (!VAR  &&  linelen != length)
        { fprintf (stdout, "line %4d: Changing record length ",count);
          fprintf (stdout, "(first = %d, this = %d)\n",length,linelen);
        }

      /* Check for the correct carriage control: */

      if (LF)
        { if (line[linelen-1] != '\n'  ||  line[linelen-2] == '\r')
            { fprintf (stdout, "line %4d: Invalid carriage control\n",count); }
        }
      else
        { if (line[linelen-1] != '\n'  ||  line[linelen-2] != '\r')
            { fprintf (stdout, "line %4d: Invalid carriage control\n",count); }
        }

      /* Now check each individual character in the line to make sure it is
         in the accepted PDS character set for text files:
      */

      linelen = (LF)? linelen - 1 : linelen - 2;  /* Characters to check */
      for (i=0; i<linelen; i++)
        { k = line[i];
          if (k<32 || k>126)
            { fprintf (stdout, "line %4d: Invalid character in byte %d.\n",
                                count,i);
            }
        }
    }

  /* Report record length extrema: */


  fprintf (stdout, "Maximum record length: %d bytes\n",maxlen);
  fprintf (stdout, "Minimum record length: %d bytes\n",minlen);

/*---------------------------------------------------------------------------*/

  /* Close files and leave: */

  if (ifp != stdin) fclose(ifp);
  exit(0);
}
