.\" Manual page for the ISO 9660 name compliance checker
.\"
.\" 31 January 2007, A.C.Raugh
.\" 21 Feb 2007, acr: Added total path checking
.\"
.TH CHKISONAMES L "21 February 2007"
.SH NAME
chkisonames \- check file and directory names for ISO 9660 and PDS compliance
.SH SYNOPSIS
.B chkisonames
.RB "[\| " \-l " | " \-u " \|] "
.RB "[\| " \-s " \|]  [\| "
.IR directory " \|] "
.SH DESCRIPTION
.LP
.B chkisonames
checks all the directory and file names under the given directory for 
compliance with the ISO 9660 standard constraints.  It also, by default, 
checks for compliance with the PDS constraints, which are a subset of the
ISO 9660 requirements.  The latter behaviour can be turned off via
the \-s option.
.LP
ISO 9660 file and directory identifiers are limited to the character set
[A-Z0-9_].  Directory identifiers may be no more than 31 characters long.
File identifiers must contain either a name or an extension (or both), the
sum total length of which may not exceed 30 characters. If both a name and
extension are present, the separator character is a full stop ('.'), which
is not included in the total length calculation.
.LP
ISO 9660 places the following constraints on the fully qualified file name:
.LP
.RS 3
Directory hierarchies may not exceed eight levels
.LP
The sum of the lengths of all directories identifiers, the length of the file
identifier, and the number of directories in the path can not exceed 255.
.RS -3
.LP
By default this routine allows either upper or lower case.  It will flag
mixed case in a single file or directory identifier as a potential problem,
but it does not attempt to find names that will collide if case is forced one
way or the other.  Neither will it complain if directory and file names are
in different cases.
The user may specify either a lowercase or uppercase 
constraint using the \-l or \-u option, respectively.
.LP
In addition to the ISO 9660 restrictions, PDS further requires that no
file name be longer than 27 characters and no
file extension be longer than 3 characters. 
When PDS checking is enabled, a warning will also be issued for file
identifiers that have zero-length names or extensions.
.LP
if no directory is specified for the search, the current working directory 
will be checked.
Output is to standard out.
.\"---------------------------------------------------------------------------
.SH OPTIONS
.TP
.B \-l
Require lowercase identifiers.  This will cause any uppercase characters in
file or directory identifiers to be flagged as bad.  \-l and \-u are
mutually exclusive.
.TP
.B \-u
Require uppercase identifiers.  This will cause any lowercase characters in
file or directory identifiers to be flagged as bad.  \-u and \-l are
mutually exclusive.
.TP
.B \-s
Shut up about PDS requirements.  This will suppress checking for the tighter
PDS archive constraints on file names.
