.\" Manual page for the 'chkpdssum' routine
.\"
.\" 19 Jul 2006, a.c.raugh.
.\" 21 Sep 2006, ACR:
.\" 06 May 2008, ACR: Added "--sbn-ignore","--exclude"
.\"
.TH SAMPLE L "06 May 2008"
.SH NAME
chkpdssum \- Check the contents of an MD5 checksum file against a PDS volume 
or directory tree
.SH SYNOPSIS
.B chkpdssum
.RB " [\|" \-i "\|] [\|" \-f 
.IR checksum_file "\|]"
.RB " [\|" \-\-sbn\-ignore "\|]"
.RB " [\|" \-x " or " \-\-exclude
.IR pattern "\|] [\|" 
.BR "\-o  output_file" "\|] [\| " root_dir " \|]"
.\"------------------
.SH DESCRIPTION
.LP
.B chkpdssum
Runs a checksum on the files in the directory tree starting at
.B root_dir
and compares the results to the listing found in the PDS checksum.tab
file included in the volume.
More specifically, this routine takes as input the file output by the
.B mkpdssum
routine, whether or not this is actually in a PDS volume format.
That is, path names are trimmed in the same way.  The PDS label for
the checksum file is never referenced, and need not be present.
.LP
When
.B chkpdssum
is run on the root of a PDS volume, it will wutomatically look for
a "checksum.tab" (or "CHECKSUM.TAB") file in the volume
index/ subdirectory.  
Failing that, the current working directory is checked for a file named
"checksum.tab" or "CHECKSUM.TAB".
The user may supply another name and location via the
.I \-f 
option.
.LP
If no root directory is specified, the current working directory is used.
Output is dircted to STDOUT unless an output file name is specified via
the \-o option.
.LP
.B mkpdssum
reports three different error conditions: 1) the checksum calculated 
from the disk file differs from that in the checksum table file; 2)
a file is found in the root directory tree that does not have a checksum
in the checksum table; and 3) a file listed in the checksum table file
does not have a corresponding file in the root directory tree.
The checksum file itself is ignored if it appears in the directory tree,
and thus there will be no message indicating a missing or invalid checksum
for that file, or for it's label, in the case of PDS volumes.LP
If no errors are found at all a message will be displayed indicating
success.
.LP
The \-x option (or the equivalen \-\-exclude)
can be used to specifically exclude matching paths and/or
filenames from the check - whether they occur in the checksum table or 
in the directories.  It may be repeated as needed to specify multiple 
patterns to match.
.\"------------------
.SH OPTIONS
.TP
.B \-i
Ignore file name case.  That is, all file names and paths that differ
only in case between the root directory and the checksum file listing
will be considered to be the same file. 
The default is to require file paths and names to match exactly.
.TP
.BI \-f " file"
Use the checksum listing in "file" rather than looking for a 
"checksum.tab" file.
.TP
.BI \-o " outfile"
Direct the output to "outfile".  Default is to send output to STDOUT.
.TP
.BI \-x " pattern" "or \-\-exclude" " pattern"
Exclude all files whose paths or names match "pattern" at any point.
Only one string can be specified, but the \-x option may be repeated as
needed
to specify multiple strings.  The matching paths/files will be ignored
without comment
both in the checksum table and when encountered in the directory tree.
.TP
.B \-\-sbn\-ignore
This option is supplied as a shortcut for ignoring the support files and 
directories used in the SBN online archive.
The patterns to ignore are hardcoded near the beginning of the program
source file.
.\"------------------
.SH NOTES
.LP
This routine uses the Perl Digest::MD5 module to calculate the check
sums.
.LP
The output of the 'md5sum' or similar utilities may be used as 
input to this routine, if the directory paths align appropriately.
Note that binary file flags (as produced by 'md5sum', for example)
are ignored.
