.\" Manual page for the CHUNKDIR (directory spliting reporter) Routine
.\" 2007 Jan 23 Created Man Page
.\"
.TH CHUNKDIR L "24 Jan 2007"
.SH NAME
.B chunkdir
\- Suggests a way to split a directory's root folders and files to fit
on multiple volumes of a specified volume size.
.SH SYNOPSIS
.B chunkdir
.RB "[ " \-b " ] [ " "\-o "
.I "out_file"
.RB " ] [ " \-p " ] [ " "\-s"
.IR "scalar" " ] " size " [ " directory " ]"
.SH DESCRIPTION
.LP
The main purpose of
.B chunkdir
is to split datasets across multiple volumes or medias of a given
.IR size .
The utility can also be used to split normal directories into chunks
of a size no greater than
.IR size .
.LP
.B chunkdir
converts the volume
.I size
in bytes.  It then creates a list of all root folders and a
list of root files found in the
.I directory
ignoring hidden files or folders.  After that it starts to print
the results' report.  A short summary of the inputed and calulated
values will then be printed to the screen.
.LP
This utility goes through the root files list, then the root folders
list, one entry at a time, calculating the total size (for a folder,
itself and all of its contents including hidden files/folders; and for
a file, just its own size) rounding up to the nearest block size
(512KB).  This amount is added to a counter that keeps track of the
capacity of a volume.
.LP
.B IF
the counter exceeds the volume
.I size
then the counter is set to equal the last amount added, prints a
message that a new volume has been reached, and prints the file/folder
path to the screen.
.B ELSE IF
there were priorly no files/folders listed for this volume then an
error is printed stating the file/folder is too large, after which it
prints the file/folder path to the screen, a new volume label is
started, and the counter is reset to zero.
.B ELSE IF
the counter size equals the volume
.IR size ,
then a warning is printed, the file/folder is printed to the
screen, a new volume label is started, and the counter is reset to
zero.
.B  ELSE
the file/folder path is just printed to the screen.   This
process is repeated until both the file and folder lists are
exhausted.
.LP
This utility will at the last tell the user if there were any
WARNINGS or ERRORS encountered during the process.  All errors,
warnings, status reports, etc are all commented out using the
.B #
character.  Only folder and file paths will not be commented out.
.SH INPUT VALUES
.TP
.I size
This REQUIRED value specifies the volume or media size that a
directory is to be split across.  This can be an integer or a number
with no more then two decimal places. You may also include a suffix
signifying the scalar of the size, either
.IR K " for Kilobytes, " M " for Megabytes, " G " for Gigabytes, or " T
for Terrabytes.  EX: "4.7G" for 4.7 gigabytes.  This scalar may also
be specified using the
.B \-s
option.  If no scalar is provided, the size is assumed to be in megabytes.
.TP
.I directory
This OPTIONAL value specifies the directory that you wish to have
split.  If nothing is provided it is assumed to be the current directory.
.SH OPTIONS
.TP
.B \-b
Will print all discarded files/folders (if any) as a single volume (no
matter the size) with the volume label of
.IR 0 .
This option is only effecive if used in conjunction with the
.B \-p
.R option.
.TP
.BI \-o " out_file"
Will print the report to the specified path
.I out_file
and to STDOUT.
.TP
.B \-p
This option will exclude root files and root folders that are not
normally in a PDS dataset.
.B chunkdir
will exclude any files or folders that are in ALL CAPS, or the
.I dataset.html
file.  WARNING: If a root file/folder contains no alphabetic
characters, the utility will assume it is in ALL CAPS.
.TP
.BI \-s " scalar"
When this option is used, the scalar value for
.I size
will be either
.IR K " for Kilobytes, " M " for Megabytes, " G " for Gigabytes, or " T
for Terrabytes.  If this option is used,
.I size
must be an integer.
.SH NOTES
.LP
The user must have read permissions for all files/folders contained
inside of
.IR directory .
If using the
.B \-o
option, the user must also have the necessary permissions to create a
file in the specified
.I out_file
location.
.LP
.B chunkdir
does not see any of the hidden files or folders at the root level of
the
.IR directory .
If you want chunkdir to include these files/folders, temporarily make
them unhidden, and keep in mind that the report will show them as not
hidden.
.LP
.B chunkdir
does not like to use soft links.  Unexpected results may occur if they
are found inside of the
.IR directory ,
which may include being ignored or causing the utility to crash or die
with error.
.LP
.B chunkdir
uses the
.IR "getopts.pl" ", " "File::Basename" ", " "Cwd" ", " "File::Find"
.RI ", and " "File::stat" " utilities or packages."
.LP
.I size
cannot start with a decimal point.  In these cases put a zero to the
left.  EX: "0.5"
.SH ABOUT
.LP
This utility is a perl script completed on Nov 29 2006, by Tilden F
Barnes IV.  Perl version 5.8.5 for i386-linux-thread-multi is what was
used to build and initually run this script.  If you have any
questions about the code feel free to contact me at
.I "getsuno.fodomo@gmail.com"

