#!/usr/bin/perl

#  Routine to fix up DATA_TYPEs in old PDS TABLE labels.  The following
#  DATA_TYPE conversions are made:
#
#        Old             ASCII Table         Binary Table
#
#       COMPLEX      =>  ASCII_COMPLEX       IEEE_COMPLEX
#       FLOAT        =>  ASCII_REAL          IEEE_REAL
#       INTEGER      =>  ASCII_INTEGER       MSB_INTEGER
#       REAL         =>  ASCII_REAL          IEEE_REAL
#
#  Format:
#
#       % fixdt [ input_file [ output_file ] ]
#
#  If no input/output files are specified, the stdin/stdout is used.
#
#  20 March 1996, acr.
#
#  Modification History:
#
#    01 May 1996, acr:  Fixed bug which caused INTERCHANGE_FORMAT in quotes
#                       to be ignored; added Binary TABLE support.
#
#==============================================================================

# Retrieve file names, if any, and open:

if (@ARGV > 2)
  { die "Usage: fixdt [ input_file [ output_file ] ]\n"; }

if (@ARGV > 1)
  { open (OUTPUT, ">$ARGV[1]") || die "Could not open $ARGV[1] for output."; }
else
  { open (OUTPUT,">-") || die "Could not open stdout."; }

if (@ARGV > 0)
  { open (INPUT,$ARGV[0]) || die "Could not open $ARGV[0] for input."; }
else
  { open (INPUT,"-") || die "Could not open stdin."; }



# Step through the input label, outputting one line at a time.  Keep and eye
# out for the INTERCHANGE_FORMAT and keep track of it.  Allow for the 
# possibility that it might change through different OBJECTs in the file, but
# always use th elast encountered value.

$interchange = "not found";

while ($line=<INPUT>)
  { chop $line;

    if ($line =~ /INTERCHANGE_FORMAT\s*=/)
      { $interchange = $line;
        $interchange =~ s/^.*=\s*("|)\s*//;
        $interchange =~ s/\s*("|)\s*$//;

        if ($interchange ne "ASCII"  &&  $interchange ne "BINARY")
          { if (@ARGV > 0)
              { print STDERR "Note: $ARGV[0] has \"$interchange\" INTERCHANGE_FORMAT.\n"; }
            else
              { print STDERR "Note: Input has \"$interchange\" INTERCHANGE_FORMAT.\n"; }
            print STDERR "    output_file = input_file.\n";
          }
      }

    if ($line =~ /^\s*DATA_TYPE\s*=/  &&  $interchange eq "ASCII")
      { 
        # DATA_TYPE fixes.  There are three forms of each - two which
        # do not change the length of the record (if there is sufficient
        # trailing blank space to absorb the additional characters) and one 
        # which does.  If the one substitution succeeds, the succeeding ones
        # will be bypassed.

        $line =~ s/(=\s*)COMPLEX      /$1ASCII_COMPLEX/;
        $line =~ s/(=\s*)"COMPLEX"      /$1"ASCII COMPLEX"/;
        $line =~ s/(=\s*)("|)COMPLEX("|)/$1ASCII_COMPLEX/;

        $line =~ s/(=\s*)FLOAT      /$1ASCII_REAL/;
        $line =~ s/(=\s*)"FLOAT"      /$1"ASCII REAL"/;
        $line =~ s/(=\s*)("|)FLOAT("|)/$1ASCII_REAL/;

        $line =~ s/(=\s*)INTEGER      /$1ASCII_INTEGER/;
        $line =~ s/(=\s*)"INTEGER"      /$1"ASCII INTEGER"/;
        $line =~ s/(=\s*)("|)INTEGER("|)/$1ASCII_INTEGER/;

        $line =~ s/(=\s*)REAL      /$1ASCII_REAL/;
        $line =~ s/(=\s*)"REAL"      /$1"ASCII REAL"/;
        $line =~ s/(=\s*)("|)REAL("|)/$1ASCII_REAL/;
      }

    elsif ($line =~ /^\s*DATA_TYPE\s*=/  && $interchange eq "BINARY")
      {
        $line =~ s/(=\s*)COMPLEX     /$1IEEE_COMPLEX/;
        $line =~ s/(=\s*)"COMPLEX"     /$1"IEEE COMPLEX"/;
        $line =~ s/(=\s*)("|)COMPLEX("|)/$1IEEE_COMPLEX/;

        $line =~ s/(=\s*)FLOAT    /$1IEEE_REAL/;
        $line =~ s/(=\s*)"FLOAT"    /$1"IEEE REAL"/;
        $line =~ s/(=\s*)("|)FLOAT("|)/$1IEEE_REAL/;

        $line =~ s/(=\s*)INTEGER    /$1MSB_INTEGER/;
        $line =~ s/(=\s*)"INTEGER"    /$1"MSB INTEGER"/;
        $line =~ s/(=\s*)("|)INTEGER("|)/$1MSB_INTEGER/;

        $line =~ s/(=\s*)REAL     /$1IEEE_REAL/;
        $line =~ s/(=\s*)"REAL"     /$1"IEEE REAL"/;
        $line =~ s/(=\s*)("|)REAL("|)/$1IEEE_REAL/;
      }


    # Print the line:

    printf OUTPUT "$line\n";
  }

#  Done.

close(INPUT);
close(OUTPUT);
 
