#!/usr/bin/perl

# Routine to remove the trailing "Z" from the values of PDS *_TIME keywords.
#
# Format:  fixztimes file1 [ file2 [...] ]
#
# The input file is overwritten.  The routine only looks for keywords that
# end in "_TIME".  If the value of such a keyword is not quoted and ends in
# a 'Z', the 'Z' is removed (in unpadded files) or replaced by a blank (in
# padded ones).  
#
# This is not a particularly clever routine, and it will be defeated by 
# odd formatting or obscure NATIVE time strings that just happen to be
# identifiers ending in 'Z', so check your results.
#
# If no file names are provided, input is read from STDIN and printed to
# STDOUT.
#
#==========================================================================
# Check for arguments:

if (@ARGV == 0) 
  { die "Usage: fixztimes file1 [ file2 [...] ]\n"; }

# Constants:

$TMPFILE = "_&_TMP";

while ($infile = shift(@ARGV))
  { open(IN,$infile) || die "Could not open $infile for reading ($!)";
    open(OUT,">$TMPFILE") || die "Could not open $TMPFILE for writing ($!)";

    while ($line=<IN>)
      { if ($line =~ /^\s*[A-Z0-9_]+_TIME\s*=/)
          { $line =~ s/Z$//;          # Remove unpadded trailing 'Z'
            $line =~ s/([0-9])Z /$1  /;   # Replace padded trailing 'Z'
          }
        printf OUT $line;
      }

    close(IN);
    close(OUT);

    rename $TMPFILE, $infile;
  }

# All done.
