#!/usr/bin/perl

use Getopt::Std;

#  Routine to read in an "allrefs.out" file, format it as REFERENCE objects
#  and write it.
#
#  Format:  % fmt_allrefs [ -o <output> ] [ <input> ]
#
#  If no input file is given, "allrefs.out" is assumed.  If no output file
#  is given, "allrefs.cat" is assumed.
#
#  30 April 2003, A.C.Raugh
#  21 Sep 2005, ACR: Fixed stupid bug that left closing quote of last
#                    reference
#
#===========================================================================

getopts('o:');

if (@ARGV > 1)
  { die "Usage: fmt_allrefs [ -o <output> ] [ <input> ]\n"; }

$input  = (@ARGV == 1)? $ARGV[0] : "allrefs.out";
$output = ($opt_o)?     $opt_o   : "allrefs.cat";

# Open files:

open (IN,$input) || die "Could not open '$input' for input.";
open (OUT, ">$output") || die "Could not open '$output' for output.";

# Write some header information to the output file:

printf OUT "PDS_VERSION_ID      = PDS3\n";
printf OUT "LABEL_REVISION_NOTE = \"\n";
printf OUT "  Created by 'fmt_allrefs' from '$input'.\n";
printf OUT "  \"\n";

# Loop through the input file:

undef $lastid;
undef @ref;
$r = 0;
$refcount = 0;

while ($line=<IN>)
  { $line =~ s/\s+$//;   # Trim blanks and delimiters

    ($id, $num, @rest) = split(/\|/,$line);

    # The "@rest" array is just in case some idiot allows a vertical bar
    # to creep into the text of the reference.  We re-assemble it here:

    if (@rest > 1)
      { $text = join("|",@rest); }
    else
      { $text = $rest[0]; }

    # Initialize if this is the first ID:

    if (!$lastid)
      { $refcount = 1;
        $lastid = $id;
      }

    # If we're continuing the previous reference, add the line to the
    # reference buffer:

    if ($id eq $lastid)
      { $ref[$r] = $text;
        $r++;
      }
    else
      { # Write the last reference:

        printf OUT "\n";
        printf OUT "OBJECT     = REFERENCE\n";
        printf OUT "  REFERENCE_KEY_ID = \"$lastid\"\n";
        printf OUT "  REFERENCE_DESC   = \"\n";
        for ($i=0; $i<$r-1; $i++)
          { printf OUT "    $ref[$i]\n"; }
        printf OUT "    $ref[$r-1]\"\n";       # Add closing quote
        printf OUT "END_OBJECT = REFERENCE\n";

        # Set up for the next one:

        $ref[0] = $text;
        $r      = 1;
        $lastid = $id;

        $refcount++;
      }

    # Next line:
  }

# Write the reference still in the buffer:

printf OUT "\n";
printf OUT "OBJECT     = REFERENCE\n";
printf OUT "  REFERENCE_KEY_ID = \"$id\"\n";
printf OUT "  REFERENCE_DESC   = \"\n";
for ($i=0; $i<$r-1; $i++)
  { printf OUT "    $ref[$i]\n"; }
printf OUT "    $ref[$r-1]\"\n";
printf OUT "END_OBJECT = REFERENCE\n";

# Finish off the output file:

printf OUT "\nEND\n";

# Close up and we're done:

close(IN);
close(OUT);

printf "$refcount REFERENCE objects written to $output.\n";
