#!/usr/bin/perl

use Getopt::Std;
use lib "/n/sbnops01/lcltools/lib/perl5";
require "nextPDSODL.pl";

#
# gettargets
#
# Routine to read through the label files in a directory tree and collect the
# TARGET_NAME values, then format them into a DATA_SET_TARGET object list for
# inclusion in the data set catalog file.
#
# Format:  % gettargets [-a] [-o <output_file] [-r] [ file_list ]
#
#  where     -a      means check for attached labels
#            -o      directs output to the named file
#            -r      recurses into subdirectories
#
# 15 Feb 2002, acr.
#
# Modification History:
# ---------------------
#
#  21 Mar 2002, ACR: Corrected stupid bug screwing up recursion.
#  18 Jan 2003, ACR: Modified output to produce a single DATA_SET_TARGET 
#                    object
#  26 Sep 2006, acr: Modified to use Getopt::Std and "use lib"
#
#=============================================================================
# Get the input arguments, if any:

getopts('ao:r');

# If there is no file list, we assume the current directory. If there is no
# output file, we assume stdout:

if (@ARGV == 0)
  { $ARGV[0] = "."; }

if ($opt_o)
  { $outfile = $opt_o; }
else
  { $outfile = "-"; }
open (OUT,">$outfile") || die "Could not open output file '$outfile'.";

# Initialize the global hash:

undef %target;

# Loop through the input list:

undef $flist;
undef $dlist;
$fl = 0;
$dl = 0;

foreach $file (@ARGV)
  { if (-d $file)
      { $dlist[$dl] = $file;
        $dl++;
      }
    elsif ($opt_a  ||  $file =~ /\.lbl$/  ||  $file =~ /\.LBL$/)
      { $flist[$fl] = $file;
        $fl++;
      }
    else
      { printf STDERR "Can't do anything with '$file'. Ignored.\n"; }
  }

# Now loop through the files:

foreach $file (@flist)
  { &dofile($file); }

# And the directories:

foreach $file (@dlist)
  { &dodir($file); }

# Now we'll print out the results:

@targlist = sort keys(%target);
$ntarg    = @targlist;

printf OUT "  OBJECT     = DATA_SET_TARGET\n";
printf OUT "    TARGET_NAME = { \"$targlist[0]\"";
for ($i=1; $i<$ntarg; $i++)
  { printf OUT ",\n                    \"$targlist[$i]\"";}
printf OUT " }\n";
printf OUT "  END_OBJECT = DATA_SET_TARGET\n";

close(OUT);

# And we're done.

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
sub dodir

  # Routine to process label files in a directory

{ local ($dir) = $_[0];

  my (@flist,@dlist);
  my ($fl,$dl);
  my ($file);

  undef @flist;
  undef @dlist;
  $fl = 0;
  $dl = 0;

  # Open the directory and loop through the contents:

  opendir (DIR, $dir) || die "Could not open directory $dir.";
  foreach $file (readdir(DIR))
    { next if ($file =~ /^\./);
      if (-d "$dir/$file"  &&  $opt_r)
        { $dlist[$dl] = "$dir/$file";
          $dl++;
        }
      elsif ($opt_a  ||  $file =~ /\.lbl$/  ||  $file =~ /\.LBL$/)
        { $flist[$fl] = "$dir/$file";
          $fl++;
        }
    }
  closedir(DIR);

  # Call file processor:

  foreach $file (@flist)
    { &dofile($file); }

  # Call subdirectory processor:

  foreach $file (@dlist)
    { &dodir($file); }

  # And we're done.

  return 1;
}

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
sub dofile

  # Routine to process a label file (or potential label file).

{ local ($file) = $_[0];

  my ($line,$name);
  my ($not_found,$not_done);
  my ($key,$val);

  # Begin by opening the file and making sure it's a PDS label:

  open (LBL,$file) || die "Could not open $file for reading.";

  $not_found = 1;     # Flag labels without TARGET_NAMEs
  $line = &nextPDSODL(LBL);
  ($key,$val) = splitODLline($line);

  return 0 if ($key ne "PDS_VERSION_ID");

  # All right, we have a label file. We now search through it until we
  # either find a TARGET_NAME, or come to the END statement:

  $not_done = 1;
  while ($not_done && $not_found)
    { $line = &nextPDSODL(LBL);
      last if (!$line);

      ($key,$val) = splitODLline($line);
      last if ($key eq "END");

      if ($line =~ /^\s*TARGET_NAME\s*=/)
        { # We may have multiple TARGET_NAME values, so we have to 
          # be careful, here:

          $val =~ s/"//g;

          if ($val =~ /,/)  # Commas only occur between series elements
            { $val = substr($val,1,(length($val)-2));

              @list = split(/,/,$val);
              foreach $val (@list)
                { $val =~ tr/a-z/A-Z/;
                  $target{$val}++;
                  $not_found = 0;
                }
            }
          else
            { $target{$val}++; 
              $not_found = 0;
            }
        }
    }

  # Close up and return:

  close(LBL);

  return 1;

}

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
