#!/usr/bin/perl

use Getopt::Std;

# 
#  Routine to basically 'grep' on a pattern through the DESCRIPTION fields 
#  in the pdsdd.full file.
#
# Format: % grepdd [-i] [-a] [-d <dictionary] <pattern>
#
#   where  -i  indicates case should be ignored
#          -a  requires all patterns to be matched to score a hit (AND)
#          -d  provides the name of an alternate dictionary file 
#              to be searched (default dictionary is ignored)
#
#  Output is the name and description of any matching element or object.
#  Default is to report the object if any one of the input patterns matches.
#
# 15 May 2003, A.C.Raugh
#
#============================================================================ 

$PDSDD = "/n/sbnops01/lcltools/doc/pdsdd.full";

$TRUE  = 1;
$FALSE = 0;

# Set up:

getopts('aid:');

if (@ARGV == 0)
  { die "Usage: grepdd [-i] [-d <dictionary>] <pattern>\n"; }

else 
  { @pattern = @ARGV; }

$dd_file = ($opt_d)? $opt_d : $PDSDD;
open (DD,$dd_file) || die "Could not open dictionary file '$dd_file' ($!).";
open (OUT,"| more");

# We'll loop through the dictionary definitions, which means skipping past 
# the opening stuff until we get to the first OBJECT = *_DEFINITION line:

$line=" ";
$lc = 0;
while ($line !~ /^\s*OBJECT\s*=\s*([A-Z_]+)_DEFINITION\s*$/)
  { $line = <DD>;
    $lc++;
    
  }

# All righty. From this point we're looping through the definitions, saving
# the name, type and description fpr each object and running the grep on the
# collection DESCRIPTION contents:

$not_done = $TRUE;
while ($not_done)
  { # Get the object type:

    $line =~ /=\s*([A-Z_]+)_DEFINITION/;
    $type = $1;

    # Get the object name:

    while ($line !~ /^\s*NAME\s*=/)
      { $line=<DD>; }
    $line =~ /=\s*(\S+)\s*$/;
    $name = $1;

    # Collect all lines in the description field (without the label) in one
    # string buffer:

    while ($line !~ /^\s*DESCRIPTION\s*=/)
      { $line =<DD>; }
    $line =~ /\s*=\s*"(.*)$/;
    $desc = $1;
    $line=<DD>;
    while ($line !~ /"\s*$/)
      { $desc .= $line; 
        $line = <DD>; 
      }
    $desc .= $line;

    # Now we run the search for each pattern on the entire description buffer,
    # taking into account whether the user options:

    # ... AND matching ...

    if ($opt_a)
      { $matched = $TRUE; 
        if ($opt_i)
          { for ($i=0;$i<@pattern; $i++)
              { $matched = ($matched  &&  ($desc =~ /$pattern[$i]/mi)); 
                last if (!$matched);      # We stop checking at the first miss
              }
          }
        else
         { for ($i=0;$i<@pattern; $i++)
              { $matched = ($matched  &&  ($desc =~ /$pattern[$i]/m)); 
                last if (!$matched);      # We stop checking at the first miss
              }
          }
      }

    # ... OR matching ...

    else
      { $matched = $FALSE;
        if ($opt_i)
          { for ($i=0; $i<@pattern; $i++)
              { if ($desc =~ /$pattern[$i]/mi)
                  { $matched = $TRUE;
                    last;                 # We stop checking at the first hit
                  }
              }
          }
        else
          { for ($i=0; $i<@pattern; $i++)
              { if ($desc =~ /$pattern[$i]/m)
                  { $matched = $TRUE;
                    last;                 # We stop checking at the first hit
                  }
              }
          }
      }

    # If we found a match, we print the name, type and description to the
    # output:

    if ($matched)
      { if ($type eq "ELEMENT")
          { $type = "Element"; }
        elsif ($type eq "GENERIC_OBJECT")
          { $type = "Generic Object"; }
        else
          { $type = "Specific Object"; }

        printf OUT "\n";
        printf OUT "%-60.60s ($type)\n", $name;
        printf OUT $desc;
      }

    # Next definition:

    while (!eof(DD) && $line !~ /^\s*OBJECT\s*=\s*([A-Z_]+)_DEFINITION\s*$/)
      { $line=<DD>; }

    $not_done = $FALSE if (eof(DD));
  }

# Close up and we're done:

close(OUT);
close(DD);
