.\" Manual page for the PDS TABLE text file label generator, LABELTEXT
.\"
.\" 02 May 2000, a.c.raugh
.\" 23 Aug 2000, acr: fixed a couple bugs and modified NOTE handling.
.\"
.TH LABELTEXT L "23 Aug 2000"
.SH NAME
labeltext \- Generate PDS TEXT labels for unlabeled text files
.SH SYNOPSIS
.B labeltext
.RB "[\| " \-r " \|] [\| " \-d " \|] " "<file list>"
.SH DESCRIPTION
.LP
.B labeltext
reads through the list of files and directories looking for unlabeled text
files and prompts the user for the required information to generate those
labels.
.LP
When an unlabeled text file is found, the user is prompted to supply
two required fields: PUBLICATION_DATE and a descriptive NOTE. PUBLICATION_DATE
defaults to the current date; no initial default NOTE value is supplied.
In both cases the entered value is retained as the new default.
.LP
Options allow the user to specify whether the labels should be attached (in
the same file as the text) or detached. Detached labels are written into a 
file with the same name as the text file and an extension of ".LBL" or ".lbl",
as appropriate.
.LP
The input list may consist of one or more file names and directories. If no
arguments are provided, the current directory is assumed. Only files meeting
the criteria listed below for "unlabeled text files" are affected.
.\"---------------------------------------------------------------------------
.SH OPTIONS
.TP
.BI \-r
Indicates that
directories in the argument list should be searched recursively for unlabeled
text files.
.TP
.BI \-d
Indicates that the labels produced should be detached, i.e., in separate files
from the text. The default action is to attach the labels directly to the 
text, overwriting the original file.
.\"---------------------------------------------------------------------------
.SH USER INPUT
.LP
As each unlabeled text file is encountered, the fully qualified file name and
the first five lines of the file are displayed to help in 
identifying the file contents. The user is then prompted to provide the 
required information.
.TP
PUBLICATION_DATE
.br
This is the date of publication of the text file itself.
The initial default value for this field is the current date. Once the user
enters a new date, the last date entered is retained as the default for the
next file. 
.sp
.B NOTE:
Entering 's' (or 'S') in response to the PUBLICATION_DATE prompt will skip
the present file (i.e., provide no label at all) and go on to the next
unlabeled text file. Current default values are retained.
.TP
NOTE
.br
This field should contain descriptive information about the text file. Multiple
lines may be entered. The end of the note is indicated by entering a period
(".") alone on a line.
No initial default value is provided for this field.
Once a value has been entered,
it is retained as the new default value.
The first line of the default NOTE is displayed in the prompt, with an 
ellipsis (...) indicating that a NOTE value continues onto subsequent lines.
.sp
If a null line is entered in response to the prompt, the current default is
used.
If a terminator line (".") is entered in response to the prompt, the default
value is deleted and the user is prompted until a non-null NOTE value is
entered.
To insert a line break between the opening quotation marks and the beginning 
of the note text, enter one or more blank spaces in reponse to the prompt before
hitting <RETURN>.
Spacing lines and blank padding are retained as entered in the note text.
NOTE lines are character-wrapped as necessary to maintain the 80-byte length
restriction in the output label.
.LP
It is not possible to force a null NOTE value into the output label, although it
is possible to write a NOTE which contains only a string of blanks. Such a 
value, however, will not pass PDS validation tests.
.\"---------------------------------------------------------------------------
.SH UNLABELED TEXT FILES
.LP
Unlabeled text files must meet the following criteria:
.LP
.RS +0.5i
.TP
1
They must have a file extension of ".TXT" or ".txt".
.TP
2
They must not have an associated ".LBL" or ".lbl" file in the same directory.
.TP
3
They must not already have an attached PDS label.
.TP
4
They must have non-zero length.
.TP
5
They must pass a system test for identifying text files.
.RS -0.5i
.LP
Attached PDS labels are recognized by reading through the file until the 
first non-blank, non-comment line is encountered. If this line begins with
the string "PDS_VERSION_ID =", the file is assumed to be labeled and no further
checking is done. If any other string is encountered, the file is assumed
to be unlabeled. No attempt is made to check validity of existing attached
or detached labels.
.\"---------------------------------------------------------------------------
.SH OUTPUT LABELS
.LP
All PDS labels generated by this routine will
have 80-byte, fixed-length lines with carriage-return/linefeed (CR/LF)
record delimiters. This is true for both attached and detached labels.
Labeltext does not attempt to determine record lengths or delimiters in the
text files even when the label will be attached - it is assumed this detail
has already been taken care of.
If not, the user will have to allow for further editing of the output files.
.LP
All PDS labels created will use the TEXT object. Detached labels will have
the appropriate pointer, with the file name appearing in the label in 
the same case as it appears on the system. Detached labels will not be
created for text files which already have attached labels (and conversely).
.\"---------------------------------------------------------------------------
.SH NOTES
.LP
.B labeltext
is a quick & dirty approach to labeling the miscellaneous text files appearing
on PDS volumes. Descriptive NOTE values should be given wherever possible. If
place-holder text is added via this routine, it should be replaced with 
something appropriate prior to archiving.
.LP
.B labeltest
makes no attempt to determine if the text file is valid or formatted in any
specific manner. It will write a label with 80-byte CR/LF delimited records
regardless of what the actual text file looks like.
