.\" Overview man page section for lcltools PDS file handling utilities
.\"
.\" 08 Mar 1996, acr.
.\" 27 Mar 1996, acr: updated sbnlc & sbnlblchk
.\" 01 May 1996, acr: updates fixdt
.\" 12 Jun 1996, acr: added 'tblundel'
.\" 30 Sep 1996, acr: added 'mklcldd'
.\" 22 Nov 1996, acr: added 'sbnlv'
.\" 22 Apr 1997, acr: added 'lblsumm'
.\" 27 Jan 1998, acr: added 'addcolnum'
.\" 18 Feb 1998, acr: added 'tbltmpl'
.\" 26 Oct 1998, acr: added 'rmcolumn'
.\" 11 Dec 1998, acr: added 'addcolhdr'
.\" 20 Jan 1999, acr: added 'checkids'
.\" 20 Apr 1999, acr: added 'checkpdstext'
.\" 04 May 2000, acr: added 'labeltext'
.\" 16 May 2000, acr: added 'showrefkeys' & 'sortref'
.\" 13 Apr 2001, acr: added 'pdstv', removed 'atv' and 'btv'
.\" 18 Jun 2001, acr: added 'linkchk'
.\" 25 Oct 2001, acr: added 'detachpds'
.\" 15 Jan 2002, acr: renamed 'linkchk' to 'pdslinkchk'
.\" 15 Mar 2002, acr: added 'gettargets'
.\" 02 May 2003, acr: updated for recent additions
.\" 15 May 2003, acr: added 'grepdd'
.\" 09 Jul 2003, acr: added 'addquotes' and 'fixqt'
.\" 13 Feb 2004, acr: added 'gather_ref'
.\" 06 Aug 2004, acr: added 'make_lcldd'
.\" 23 Sep 2005, acr: added 'fixztimes','split_ref'
.\" 19 Jan 2006, acr: added 'mkvolidx'
.\" 29 Jan 2007, acr: added Catch-up for relatively recent routines
.\" 31 Jan 2007, acr: added 'chkisonames'
.\" 16 Feb 2007, acr: added 'mkcumidx'
.\" 06 Mar 2008, acr: added 'vc_*' routines
.\" 14 Mar 2008, acr: added 'vc_index'
.\"
.\"---------------------------------------------------------------------------
.SS PDS FILE UTILITIES
.sk 2
.LP
These routines are useful for handling PDS labels and catalog files and for
working with the PDS Data Dictionary (PSDD).
.LP
.TP
.B addcolhdr
Add a column label header to a PDS ASCII table data file and adjust the 
label accordingly
.TP
.B addcolnum
Adds COLUMN_NUMBER elements to PDS labels containing COLUMN definitions
.TP
.B addquotes
Forces quotes around all string values in a PDS ODL file
.TP
.B change_dsid
Systematically changes DATA_SET_ID values in a directory tree.
.TP
.B checkids
Search label and catalog files for undefined _NAME and _ID fields and 
unreferenced catalog objects
.TP
.B checkpdstext
Check PDS text files (labels and catalogs) for invalid characters, record
lengths and line delimiters
.TP
.B chkpdssum
Check the contents of a PDS volume against the checksum.tab file generated by
.B mkpdssum.
.TP
.B chkisonames
Check a directory tree for file and directory identifiers that don't meet
ISO 9660 (and PDS) requirements
.TP
.B chunkdir
Divide a directory into chunks of a specified size (generates a listing to 
be used for dividing up the directory)
.TP
.B detachpds
split PDS files with attached labels into separate detached label and data
files.
.TP
.B dsids
generates a list of unique DATA_SET_ID values found in a set of PDS 
detached labels
.TP
.B dstree
create PDS volume OBJECTs to describe the data sets in a directory tree
.TP
.B fixdt
fix DATA_TYPE fields in a PDS label describing TABLE data (ASCII or binary)
to conform to current standards version
.TP
.B fixqt
Wrapper to run "addquotes" on a set of PDS ODL files, forcing quotes around 
string values and overwriting the input
.TP
.B fixztimes
Removes the trailing "Z" from PDS/ODL file keywords ending with the TIME
classword
.TP
.B fmt_allrefs
format the "allrefs.out" file as downloaded from PDS CN into an ODL-formatted
reference catalog file
.TP
.B gather_ref
extract references from "allrefs.cat" corresponding to input list of 
REFERENCE_KEY_ID values
.TP
.B gettargets
generate a DATA_SET_TARGET list by checking PDS data file labels for all
unique TARGET_NAME values
.TP
.B grepdd
Search for matching strings and patterns in the DESCRIPTION text of
the PDS data dictionary file
.TP
.B index
generate an index list of file sizes under a given root directory
.TP
.B labeltext
create PDS TEXT labels for unlabeled text files
.TP
.B lblsumm
show a summary of names, sizes and data types for OBJECTs in a PDS data file
label
.TP
.B lvtool
wrapper for the PDS label verifier tool (also called 'lvtool') to simplify
local use
.TP
.B make_lcldd
Utility for merging locally-defined keywords into the full PDS data 
dictionary file
.TP
.B mkpdssum
Generate a table of MD5 checksums for a PDS volume (or any) directory tree
.TP
.B mkvolidx
create the "index.tab" and "index.lbl" files for a PDS volume
.TP
.B mkcumidx
combine volume indices created by
.B mkvolidx
into a cumulative index
.TP
.B mklcldd
extract definitions for keywords and object appearing in data labels 
from main Data Dictionary to create a local dictionary for the file set
.TP
.B nullval
replace blank fields with null values in a PDS ASCII TABLE
.TP
.B pdef
return complete object definition from PSDD given an alias
.TP
.B pdsalias
return full name from PSDD given an alias
.TP
.B pdsdef
return full definition from pdsdd.full file given full element/object name;
search NAME fields for partial string matches
.TP
.B pdsidx
generate an index by extracting values from keywords in PDS labels
.TP
.B pdslinkchk
check links in HREF fields of HTML files to ensure all links are relative
and internal
.TP
.B pdstv
PDS/SBN label and data verifier for TABLE-type objects
.TP
.B ppodl
pretty-printer for PDS ODL (labels and catalog files)
.TP
.B rmcolumn
remove a COLUMN definition from a PDS ASCII TABLE label (and optionally, the
data file), and adjust COLUMN_NUMBER and START_BYTE values accordingly
.TP
.B sbnlblchk
checker for required keywords and valid 
DATA_TYPES in all PDS detached label files in a
directory structure.  Runs 
.B sbnlc
on all "*.lbl" files.
.TP
.B sbnlc
check PDS label for required PDS and SBN keywords; also check for valid
INTERCHANGE_FORMAT and DATA_TYPEs (as used at the SBN)
.TP
.B sbnlv
local label verifier for PDS labels and catalog files
.TP
.B showrefkeys
list REFERENCE_KEY_ID values for listed files and directories
.TP
.B sortref
sort a file containing REFERENCE object by REFERENCE_KEY_ID values
.TP
.B split_ref
split a file of REFERENCE objects into separate files for each
REFERENCE
.TP
.B srchpds
search the PSDD for a partial match of the input keyword name
.TP
.B srchref
search the master reference catalog file for matching REFERENCE objects
.TP
.B tbldelimit
add field delimiters to PDS ASCII TABLEs and adjust labels accordingly
.TP
.B tbltmpl
create a template for an ASCII TABLE label, with COLUMN characteristics as
determined from reading the data file
.TP
.B tblundel
remove field delimiters from PDS ASCII TABLEs and adjust labels accordingly
.TP
.B vc_files
check a PDS volume for required files and subdirectories
.TP
.V vc_index
check a PDS volume index for label validity and table completeness
.TP
.B vc_labels
check a PDS volume to ensure that every file is labelled
.TP
.B vc_refint
check a PDS volume for referential integrity
.TP
.b vc_text
check a PDS voluem to ensure that all text files meet PDS format and 
character restrictions
