#!/usr/bin/perl

use lib "/n/sbnops01/lcltools/lib/perl5";
require ODL;

exit(main());

sub main ()
{
    # parse arguments
    ($out_fn, $dd_fn, $mk_idx, $elmarr) = parse_args ();

    # if an output filename was given, send all output there
    if ($out_fn ne "")
    {
	open (STDOUT, ">", $out_fn)
	    or die("can't open output file: $out_fn");
    }

    # if the pdsdd filename was given, write it first
    system("cat", $dd_fn) if ($dd_fn ne "");
    # reformat all element definitions (sending output to stdout)
    reformat($_) foreach (@{$elmarr});

    # close the output stream.
    close(STDOUT);
    # if an index should be generated (and output wasn't sent to stdout)
    if ($out_fn and $mk_idx)
    {
	# check operating system, and call appropriate make_index program.
	if ($^O =~ /solaris/)
	{
	    system ("/n/deimos3/aducore/lcldd/code/make_index_solaris/make_index",
		    $out_fn);
	}
	elsif ($^O =~ /linux/)
	{
	    system("/n/deimos3/aducore/lcldd/code/make_index_linux/make_index",
		   $out_fn);
	}
	else
	{
	    warn("Warning - make_index not available on $^O\n");
	}
    }
    elsif ($mk_idx)
    {
	warn("Warning - cannot make index file when sending output to stdout.");
    }
    return 0;
}

sub parse_args ()
{
    my ($out_fn, $dd_fn, $mk_idx, @elements);
  parse_arg:
    while ($arg = shift (@ARGV))
    {
	if ($arg eq "-o")
	{
	    $out_fn = shift(@ARGV);
	}
	elsif ($arg eq "-d")
	{
	    $dd_fn = shift(@ARGV);
	}
	elsif ($arg eq "-i")
	{
	    $mk_idx = 1;
	}
	else
	{
	    @elements = ($arg, @ARGV);
	    last parse_arg;
	}
    }
    die(usage()) if ($#elements == -1);
    return ($out_fn, $dd_fn, $mk_idx, \@elements);
}

sub usage ()
{
    return "usage: make_lcldd [-i] [-o target_filename] [-d pdsdd_filename] elements\n";
}

sub reformat ($)
{
    # Get arguments
    my ($filename) = @_;

    print STDERR $filename."\n";

    # Declare local variables
    my ($source, $target, $sdef, $tdef);

    # Open and parse the element definition source file
    $source = ODL::create ($filename);
    # Create a new ODL object to write to
    $target = ODL::create();

    # Get the element_definition portion of the element definition file.
    # there should be only one, and it should be the only object within each
    # file. below is a basic template for element definition files:
    # > BEGIN_OBJECT = ELEMENT_DEFINITION
    # >   <STATEMENT>
    # >   ...
    # > END_OBJECT = ELEMENT_DEFINITION
    # > END
    $sobj = $source->get_object("ELEMENT_DEFINITION");

    # Create an element_definition object in the new ODL object
    $tobj = $target->new_object_statement("ELEMENT_DEFINITION");

    # Add the values to the new object from the old object, in the right order,
    # ignoring invalid values. Since we strip the quotes(that's what the
    # get_noq(...) is for, get (...) preserves quotes),values such as "N/A"
    # won't be kept since N/A isn't a valid ODL value. If it's a string with
    # non alphanumeric or underscore characters, it must be enclosed in quotes.

    $tobj->new_attribute_statement("name",
				   $sobj->get_noq("namespace_id").":".
				   $sobj->get_noq("name"))
	if ($sobj->get_attribute("namespace_id") &&
	    $sobj->get_attribute("name"));
    $tobj->new_attribute_statement("status_type",
				   $sobj->get_noq("status_type"))
	if ($sobj->get_attribute("status_type"));
    $tobj->new_attribute_statement("general_data_type",
				   $sobj->get_noq("general_data_type"))
	if ($sobj->get_attribute("general_data_type"));
    $tobj->new_attribute_statement("unit_id",
				   $sobj->get("unit_id"))
	if ($sobj->get_attribute("unit_id"));
    $tobj->new_attribute_statement("standard_value_type",
				   $sobj->get_noq("standard_value_type"))
	if ($sobj->get_attribute("standard_value_type"));
    $tobj->new_attribute_statement("minimum",
				   $sobj->get_noq("valid_minimum"))
	if ($sobj->get_attribute("valid_minimum"));
    $tobj->new_attribute_statement("maximum",
				   $sobj->get_noq("valid_maximum"))
	if ($sobj->get_attribute("valid_maximum"));
    $tobj->new_attribute_statement("minimum_length",
				   $sobj->get_noq("minimum_length"))
	if ($sobj->get_attribute("minimum_length"));
    $tobj->new_attribute_statement("maximum_length",
				   $sobj->get_noq("maximum_length"))
	if ($sobj->get_attribute("maximum_length"));
    $tobj->new_attribute_statement("description",
				   $sobj->get("description"))
	if ($sobj->get_attribute("description"));
    $tobj->new_attribute_statement("standard_value_set",
				   $sobj->get("standard_value_set")->to_string())
	if ($sobj->get_attribute("standard_value_set"));
    # write the new ODL object to the standard output
    $target->write_to_stream (STDOUT);
    return 0;
}


