.\" Manual page for the <MKCUMIDX.PL> (<create cumulative index files>) Routine
.\" 2007 Mar 8 Finished Creation of Man Page
.\"
.TH MKCUMIDX L "28 FEB 2007"
.SH NAME
.B mkcumidx
\- Creates the cumulative index files for a set of PDS volumes
.SH DESCRIPTION
.LP
.B mkcumidx 
creates a cumulative PDS index table and label using the PDS index
tables and labels from a list of volumes 
.RI ( volume_i ").  Though"
this utility does check for index file errors, using any index file
that does not meet the PDS3 standards may produce unpredictable and/or
undesired results and so should only be used with PDS3 index
files. This utility was built to be used in conjunction with the
.B mkvolidx 
utility, but can be used on a more general basis.  See the
REQUIREMENTS section for a list of specific requirements. 
.LP
Basically this utility standardizes the column widths for the index
tables into a new cumulative index table and creates a very basic
cumulative index label for it.  These cumulative index files are then
either put into each volume's index directory or if the 
.B \-o 
option is used, put into the directory specified.  The original index
files will remain unaltered. 
.LP
This utility first tests to see if all volumes contain their required
index files ('index/index.lbl and 'index/index.tab), which can be
read and that the output location(s) exist and can be written to.
With this all initial values the utility will need are created.  If
there were any errors up to this point they will at this time be
printed to the screen and then the utility will die printing the total
number of errors encountered. 
.LP
. B mkcumidx 
then opens up each index label looking for the required fields it
needs, storing these and calculating the cumulative values.  After
this the utility creates a temporary cumulative index table by opening
up each individual index table in turn, processing these lines, and
outputting them into it.  Then a temporary cumulative index label is
created.  These two temporary files are then moved to live in their
new homes, which was specified at the utility's call. 
.SH REQUIREMENTS
.LP
Each index file must be located in the 'index/ directory of its
volume.   
.B mkcumidx 
needs to be able to read these files.  Also the 'index/ directory in
each volume needs to be able to be written to unless the 
.B \-o 
option is used.  
.LP
Each index table file must be fixed-length.  There is no check for
this, for it is assumed. 
.LP
You should have a VOLUMN_ID column in your original index tables to
distinguish between each volume.  If the 
.B mkvolidx
routine was used to create the original index files then this will be
the first column in the index tables.  
.B mkcumidx 
does not check for this column but assumes it is there.
.LP
The ODL package written by Andrew Ducore will be used to extract all
needed values from the index labels.  Only the first occurrence of
these keywords will be used, with the exception of OBJECT =
INDEX_TABLE -> OBJECT = COLUMN, in which case only first number of
these equal to COLUMNS will be looked for and used.  All other data
contained in the index labels will be ignored.  The values looked for
are:  
 	FILE_RECORDS = <integer>
 	RECORD_BYTES = <integer>
 	START_TIME = <time|date> (optional)
 	STOP_TIME = <time|date> (optional)
 	OBJECT = INDEX_TABLE
 		ROWS = <integer>
 		ROW_BYTES = <integer>
 		COLUMNS = <integer>
 		OBJECT = COLUMN
 			NAME = <string>
 			START_BYTE = <integer>
 			BYTES = <integer>
 			DATA_TYPE = <string>
 			DESCRIPTION = <string> (optional)
.LP
All START_TIME and STOP_TIME values should be in either the
day-of-year or year-month-day format, but not 
interchangeably. "UNK", "N/A", or "NULL" values are also valid.  See
the NOTES section for more details.   
.LP
Only the first OBJECT = INDEX_TABLE will be used.  The first records
contained in the index table file must be for the OBJECT =
INDEX_TABLE.  There must be a number of OBJECT = COLUMN (inside of the
OBJECT = INDEX_TABLE) equal to COLUMNS.  Any that exceed this number
will be ignored; any less will cause the error "Cant call 
method 'get_statement' on an undefined value at mkcumidx line XXX."
.LP
Column X's NAME must be the same for each index label.
.LP
Only DATA_TYPE's of "CHARACTER", "DATE", "TIME", and "INTEGER" may be
used. 
.SH INPUT VALUES
.TP
.I volume_1 volume_2 volume_i
These are the volume paths that are going to be combined to create the
cumulative index files.  There must be at least two volumes; otherwise
the utility will die with error.  These volume paths may be relative
or absolute paths.  They will later be converted to absolute paths. As
a note, these volume paths are not to point to the 'index/' directory,
but to the volume itself.  The utility will verify if there is an
index directory, label and table contained inside each volume.  All of
these directory and file names should be in lowercase. 
.SH OPTIONS
.TP
.B \-h
Shows a brief description of each option for this utility.  If this
option is used, nothing else will be processed.
.TP
.BI \-o " path"
Instead of outputting the 'cumindex.lbl' and 'cumindex.tab' files in
each volume's 'index/' directory, the files will be outputted to 
.IR path .
.I path
must be an existing and writable directory otherwise the utility will
die with an error.  This 
.I path
may be an absolute or relative path.  It will later be changed by
.B mkcumidx
to an absolute path. 
.TP
.B \-v
When this option is used, 
.B mkcumidx 
will print progress reports for this and the
.B fixlen
utilities.  All such messages will be headed by the 
text "mkcumidx: " or "fixlen: " depending on the utility.  
.SH NOTES
.LP
This utility uses the 
.IR File::Copy ,
.IR Getopt::Std , 
.IR "Cwd 'abs_path'" ", and " ODL
packages and the 
.BR fixlen " utility."
.LP
Uses the '$ENV{"TMPDIR"}' command to find the directory to place
temporary files.  This code calls from the environment (Unix) the
$TMPDIR variable.  All temporary files created will be deleted after
the final cumulative index files are created. 
.LP
Only the first number of records equal to ROWS for the original index
table will be read in.  All others will be ignored. 
.LP
The default output delimiter for the cumulative index table is
hard-coded as a single comma.  The cumulative index table will still
be fixed-length. 
.LP
The cumulative index label will contain all of the keywords that would
be in index labels produced by the 
.B mkvolidx
routine.  The only exception is that 
.B mkcumidx 
will in addition, put in a line for the keyword COLUMN_NUMBER for each
COLUMN object contained in the INDEX_TABLE object. 
.LP
Each keyword value being outputted to the cumulative index label is
assumed to be less then 54 characters in length (including
quotes) in the most extreme cases.  Only the NAME and DESCRIPTION
keyword values are allowed to be of more characters in length.  In the
event the NAME keyword value is greater then 53 but less then 69
characters in length (including quotes) it will be put on the next
line indented by 8 white spaces.  If the NAME keyword value is greater
then 68 characters it will be divided across multiple lines. 
.LP
At this time FILE_RECORDS, RECORD_BYTES, and ROW_BYTES from the
original index labels are not being used for anything.  There values
are just stored in memory. 
.LP
The "NULL" value will be provided for the START_TIME or the STOP_TIME
keywords if no other value was provided in any of the original index
labels or if of those values provided there is a mixture of ONLY 
the "N/A" and/or "UNK" and/or "NULL" values.  If there are real values
provided along with "N/A" and/or "UNK" and/or "NULL" values, only the
real values will be taken into account to calculate the respective
cumulative value.  If all values found for a single keyword are 
all "N/A" or all "UNK", then the cumulative value will equal that
value. If among the real values there is a mixture of day-of-year and 
year-month-day formats, then all will be converted to year-month-day
format for calculating and output purposes.  Only the most rudimentary
conversion will be made (taking into account only leap years).  The
format will be preserved if all real values are of the same format.
As far as a valid value, this utility only checks to see if START_TIME
or STOP_TIME are not fewer than eight characters in length.  
.LP
If an individual COLUMN's DATA_TYPE for one of the original index
labels equals "DATE" or "TIME", the DATA_TYPE for this COLUMN may be
either "DATE" or "TIME" for the other index labels.  If in at least
one of these instances, DATA_TYPE = "TIME", then the cumulative index
label will have DATA_TYPE = "TIME" for this COLUMN. 
.LP
The FORMAT keywords value will be put in double quotes in the
outputted cumulative index label(s). 
.LP
Only the first non-empty DESCRIPTION found for each COLUMN will be
used.  If none are found, an empty DESCRIPTION ("") will be put in the
cumulative index label.  Also the indentation in a multi-lined
DESCRIPTION will be maintained in the cumulative index label. 
.SH UPDATES
.TP
03/01/2007
Updated calculations for START_TIME and STOP_TIME for the cumulative
index label to take into account "UNK", "N/A", "NULL", and empty
values. 
.TP
03/06/2007
Added day of year and year-month-day time converting functions.
Updated calculations for START_TIME and STOP_TIME for the cumulative
index label to take into consideration a possible mixture in TIME/DATE
formats.  If there is a mixture of day-of-year and year-month-day
formatted START_TIME/STOP_TIME in the original index labels then they
will be converted to year-month-day format for calculation purposes
and also the found cumulative value will also be outputted in this
format. 
.SH ABOUT
.LP
This utility is a perl script completed on Feb 28 2007, by Tilden F
Barnes IV.  Perl version 5.8.5 for i386-linux-thread-multi is what was
used to build and initially run this script.  If you have any
questions about the code feel free to contact me at
.I getsuno.fodomo@gmail.com
