.\" Manual page for the 'mkpdssum' routine
.\"
.\" 18 Jul 2006, a.c.raugh.
.\" 20 Sep 2006, ACR: Added "-x" option
.\" 16 Nov 2006, ACR: Added "-f" option
.\" 06 May 2008, ACR: Added "--sbn-ignore", "--exclude" options
.\"
.TH SAMPLE L "06 May 2008"
.SH NAME
mkpdssum \- Make an MD5 checksum file for a PDS volume or directory tree
.SH SYNOPSIS
.B mkpdssum
.RB " [\|" \-f "\|] [\|" \-p "\|] [\|" \-l 
.RB "|" \-u "\|] [\|" \-v
.IR VOLUME_ID "\|] "
.RB " [\|" \-\-sbn\-ignore "\|] "
.RB " [\|" \-x " or " \-\-exclude
.IR pattern "\|] [\| " root_dir " \|]"
.\"------------------
.SH DESCRIPTION
.LP
.B mkpdssum
creates the required CHECKSUM.TAB and CHEKSUM.LBL files for PDS volumes.
It can also be used to create checksum files for any directory tree.
.LP
The output checksum file is in the style produced by common utilities such 
as 'md5sum', but uses the Perl Digest::MD5 module to calculate the checksums
and sorts the list on file path and name.
The root directory is not included in the output file specifications.  The
resulting file can be used as input to utilities like 'chkpdssum' 
or 'md5sum' to check for file corruption.
.LP
If no
.I root_dir
is included on the command line, the current working directory is taken 
as the root.
The 
.B \-x
(or
.BR \-\-exclude ")"
option can be used to exclude paths and/or files that match the given
pattern, and can be repeated as many times as desired.
The
.B \-\-sbn\-ignore
option is provided as a shorthand for ignoring all the files and support 
directories associated with the SBN online archives.
.LP
.B mkpdssum
checks for the existence of an "index/" subdirectory in the root directory
given on the command line.  If one is found, 
.B mkpdssum
assumes it is working on a PDS volume and writes its output 
file 'checksum.tab' and a corresponding PDS label file called 'checksum.lbl'
in the index/ subdirectory.  File name case will match the case of the
actual index directory name.  So, for example, if
.B mkpdssum
finds an "INDEX/" subdirectory, it will create output files "INDEX/CHECKSUM.TAB"
and "INDEX/CHECKSUM.LBL".  If it finds "index/", it will create
"index/checksum.tab" and "index.checksum.lbl".
In either case, the table file will have fixed-length records with 
carriage return/linefeed record delimiters, as will the accompanying label
file.
.LP
If an index subdirectory was found, 
.B mkpdssum
will also check in the root directory for a 'voldesc.cat' (or 'VOLDESC.CAT')
file, in order to retrieve the VOLUME_ID for use in the label file.
.LP
If no index subdirectory is found, 
.B mkpdssum
will create a file called "checksum.tab" in the current working directory.
this file will not be padded and will not have an accompanying label.
.LP
All files under the root directory excluding directory files and the checksum
table and label files themselves will be included in the output checksum
table.
.\"------------------
.SH OPTIONS
.TP
.B \-f
Follow symbolic links.  This uses the "follow_fast" option to 
optimize time and space, and will detect circular links, but not
multiply-linked files.
.TP
.B \-u
Force file names to upper case in the output checksum table.
Default is to leave the case as found.
If both \-u and \-l are included, both will be ignored.
This will also force the output checksum file name to be upper
case when not working in a PDS volume structure.
.TP
.B \-l
Force file names to lower case in the output checksum table.
Default is to leave the case as found.
If both \-u and \-l are included, both will be ignored.
.TP
.B \-p
Produce just a plain checksum listing file, without padding or
a PDS label, regardless of whether an index/ subdirectory is found.
.TP
.BI \-v " VOLUME_ID "
Use the given string as the VOLUME_ID in the label for the checksum
table.  This will override any value found in a voldesc.cat file.
This option is ignored if a label is not produced (i.e., if there is
no index/ subdirectory or if the \-p option is used).
.TP
.BI \-x " pattern " "or \-\-exclude" " pattern"
Exclude files whose paths or names contain "pattern".  All files and
paths that match the string at any point will be excluded from the 
output file listing.  Only one string may be specified with each 
.B \-x
option, but the option may be repeated on the command line as many 
times as needed.
.TP
.B \-\-sbn\-ignore
Ignore the files and directories known to be used for SBN online archive
support.  These are hard-coded into a list near the top of the program
source file.
.\"------------------
.SH NOTES
.LP
This routine uses the Perl Digest::MD5 module to calculate the check
sums.
.LP
Output is formatted so that it can be used as input to the standard MD5
routines such as 'md5sum' to check a file set, as well as the complementary
.B chkpdssum
routine.
.B mkpdssum
does not attempt to indicate binary mode files as, for example, the 
md5sum utility does.
