.\" Manual page for the MKVOLIDX (volume index generator) Routine
.\"
.\" 19 Jan 2006, acr: created
.\" 16 Feb 2007, acr: Added START_TIME to output label
.\"
.TH MKVOLIDX L "16 Feb 2007"
.SH NAME
mkvolidx \- Make the required index.tab and index.lbl files for a PDS volume
.SH SYNOPSIS
.B mkvolidx
.RB "[\| " \-a " \|] [\| "  "-l | -u" " \|] "
.RB "[\| " \-p " \|] [\| " \-t " \|] [\| " \-v
.I VOLUME_ID
.RB " \|] [\| " \-r 
.I volume_root
.RB " \|] [\| " data_dir " [\| " "..." " \|] \|]"
.SH DESCRIPTION
.LP
.B mkvolidx
reads through the data directories in a PDS volume structure looking for 
PDS labels.  It extracts specific values from these labels and creates 
"index.tab" and "index.lbl" files that meet the requirements for the 
PDS volume INDEX_TABLE object.
.LP
This routine assumes it will be working in a valid PDS volume structure
and that all labels and files that it has to read are syntactically
valid.
The index created contains the following columns:
.RS 0.5i
.LP
VOLUME_ID
.br
FILE_SPECIFICATION_NAME
.br
DATA_SET_ID
.br
PRODUCT_ID
.br
PRODUCT_CREATION_TIME
.br
START_TIME
.br
TARGET_NAME
.br
INSTRUMENT_HOST_NAME
.br
INSTRUMENT_NAME
.RE
.LP
The first five are required to be in either the INDEX_TABLE data or the label.
They are included in the table created 
by this routine for generality and to facilitate
creation of cumulative indices, which require some or all of these values to be
in the table depending on circumstances.
.LP
The last four are required to be in all data labels and may be generally 
useful in indexing large data collections.
.LP
.B mkvolidx
should be run on the root of a PDS volume structure.  
Under this root directory should be one or more data subdirectories,
an index/ subdirectory, and a 
.I voldesc.cat
file.
If the user does not list data subdirectories explicitly, "data/" or "DATA/"
is used.  If neither exists, the program exits with an error.
A subdirectory called either "index/" or "INDEX/" must also exist, or the 
program will exit.
If a "voldesc.cat" (or "VOLDESC.CAT") file is found, the VOLUME_ID is read
from that file.  Alternately, the user can specify a VOLUME_ID value via
the \-v option which will override the "voldesc.cat" value, if it exists.
If there is no "voldesc.cat" and no value provided, 
"NULL_0000" is used.
.LP
MISSING_CONSTANT values are supplied for fields that are not found in 
one or more data files.
.LP
The output table file has comma-separated values with quotes around the
strings.  
Column widths are set to the maximum width of values actually in the table.
Values that are longer than the defined maximum for the keyword (i.e., 
non-compliant) are truncated.  Keywords with multiple values will generate
an error message, but processing will continue using only the first value
in the series or set.
Values that are very oddly formatted 
(i.e., broken across more than two lines, deeply
nested but degenerate sets, etc.) may throw errors or show up as
MISSING_CONSTANTs in the output file.
.LP
The user may specify the volume root directory via the
.I \-r
option; the default is the current
working directory. 
The user may also specify the data subdirectory names, if desired.  These
should be relative to the volume root.  The index may be limited to only
a part of the data tree, if desired.  
If more than one data directory is indicated, they will be sorted before
indexing.
If the user specifies any data directory, the default ("data/" or "DATA/")
will be ignored.
.LP
.B mkvolidx
tries to find both upper- and lower-case versions of standard file and
directory names like "index/" and "voldesc.cat".  The "index.tab" and
"index.lbl" files will be created in the same case as the "index/" 
directory found.  So, for example, if the volume root contains "INDEX/",
the output files will be "INDEX/INDEX.TAB" and "INDEX/INDEX.LBL".
If your volume root contains both "index/" and "INDEX/" you should
probably be writing your own software to sort it out.
.SH OPTIONS
.TP
.B \-a
Check all files.  By default,
.B mkvolidx
only indexes files that end in ".lbl" or ".LBL".  Using the \-a option
causes the program to open every non-hidden file in each directory and 
check for the "PDS_VERSION_ID" keyword in the first record.  If the
keyword is found, 
.B mkvolidx
attempts to read it as an attached PDS label and add it to the index.
If not, the file is closed and ignored.
.TP
.BI \-l " or " \-u
Forces FILE_SPECIFICATION_NAME to lowercase (\-l) or uppercase (\-u).
This affects only how the pathname appears in the output "index.tab" file.
The default is to preserve the case found when traversing the directories.
This will also force the case of the file name in the ^INDEX_TABLE pointer
of the "index.lbl" file.
If both 
.IR \-l " and " \-u
are included, both are ignored and native case is preserved.
.TP
.B \-p
Print progress messages.  The program can take quite a while to run, especially
if it has to open every file to check for attached labels.  This prints out
a line as each file is processed so the user can monitor progress.  It would
have been called "\-v", except I needed the letter for something else.
.TP
.BI \-r " volume_root "
Use the given directory as the root of the volume to be indexed.  The
names of the data directories given as arguments (if any) should be 
relative to this directory.  Default is to search in the current working
directory.
.TP
.B \-t
Preserve the temporary file.  This will cause the temporary file containing
the preliminary index to remain around after the program exits, for debugging
purposes.  The name of the file will be printed to STDERR.
Default is to remove the temporary file on program completion.
.TP
.BI \-v " VOLUME_ID "
Use the given value for VOLUME_ID.  This option overrides the VOLUME_ID in
the "voldesc.cat" file when there is one, or provides a value when there isn't.
If no other VOLUME_ID is available,
.B mkvolidx
will use "NULL_0000".
The VOLUME_ID is always forced to uppercase and checked.  If it does not meet
PDS requirements a warning is displayed, but processing continues.
.SH EXAMPLES
.LP
The simplest application is to 
.I cd
to the root of the volume you wish to index, then type:
.LP
.RS .5i
% mkvolidx
.RE
.LP
This will index all the files in the "./data" subdirectory.
.LP
To index the volume mounted on the system as "/n/disk/sl9_0030", where all
the data are in the "/n/disk/sl9_0030/data" directory:
.LP
.RS .5i
% mkvolidx -r /n/disk/sl9_0030
.RE
.LP
To index files in the data directories "2004/" "2005/" and "2006/", and 
force the file names in the index.tab to uppercase:
.LP
.RS .5i
% mkvolidx -u -r /n/disk/sl9_0030 2004 2005 2006
.RE
.LP
To do all that
.I and
provide an explicit VOLUME_ID:
.LP
.RS .5i
% mkvolidx -u -v SL9_TEST -r /n/disk/sl9_0030 2004 2005 2006
.RE
.SH NOTE
.LP
.B mkvolidx
must have write access to the "index/" (or "INDEX/") directory of the
volume root to create its output files.  Any existing files of the same
name will be overwritten without comment.
.LP
The final index file is created in two passes: the first pass collects values
into a temporary file allowing the maximum possible width for each column;
the second pass trims unneccessary blanks and adds the delimiters.  The
temporary file is create by the 
.I tempfile
function of the File::Temp package, and automatically deleted on program
exit.
If
.B mkvolidx
fails from want of disk space, check the temporary file directories first.
.LP
The START_TIME and STOP_TIME listed in the generated index.lbl file are, in
fact, the first and last START_TIME encountered in the labels.  They will 
be "N/A" only if no label contained a real START_TIME value.
