#!/usr/bin/perl

use Getopt::Std;

# Routine to replace the shell routine 'pdsdef' and 'srchpds', which are 
# hinky under Linux.
#
# Format: % pdsdef [-m] [-d <dictionary.full>] <name_string>
#   
#   where -m  indicates a partial match operation - returns a list of all 
#             element and object names (and there types) that contain the 
#             input string.
#         -d  provides the explicit name of a pdsdd.full-formatted file to
#             search instead the default file.
#
#   Default behaviour is to return the entire definition matching the input 
#   name string in its entirety.  Current PSDD structure requires that each 
#   NAME be unique.
#
# 2003-01-06, A.C.Raugh
#
# 2003-04-24, ACR: Fixed bug that chopped final letter off of items 
#                  returned by "-m" switch
# 2004-04-09, ACR: Beefed up "die" messages
# 2005-12-19, ACR: Modernized "getopts"
# 2006-04-27, ACR: Tweaked to print "OBJECT =" line at top of definition
# 2009-08-27, ACR: Fixed logical hole that was matching "END_OBJECT" string
#                  in the middle of the stupid HISTORY object description.
# 2009-11-20, ACR: Added the "-d" option
#
#============================================================================

$PDSDD = "/n/sbnops01/lcltools/doc/pdsdd.full";

$TRUE  = 1;
$FALSE = 0;

# Set up:

getopts('md:');

if (@ARGV == 1)
  { $name = $ARGV[0];
    $name =~ tr/a-z/A-Z/;
  }
else
  { die "Usage: pdsdef [-m] <name_string>\n"; }

# If a dictionary file was specified, search that.  Otherwise we open the
# default file.

if ($opt_d)
  { $PDSDD = $opt_d; }

open (DD, $PDSDD) || die "Could not open dictionary file '$PDSDD' ($!).";
open (OUT,"| more");

# Split depending on the type of match.  The '-m' option indicates a 
# partial match search:

if ($opt_m)
  { $found    = $FALSE;

    $line1 = <DD>;

    while ($line2 = <DD>)
      { if ($line2 =~ /^ *NAME *=.*$name.*$/)
          { $found = $TRUE;

            $type = $line1;
            chop $type;
            $type =~ s/^.*= *(.*)_DEFINITION\s*$/$1/;
            $match = $line2;
            chop $match;
            $match =~ s/^.*= *(\S+)\s*$/$1/;

            printf OUT "%-15.15s  $match\n",$type;
          }

        $line1 = $line2;
      }

    if ($found == $FALSE)
      { printf OUT "No matches found.\n"; }
  }

# Otherwise we look for the single definition and display it:

else
  { $found = $FALSE;

    while (($line=<DD>)  &&  !($found))
      { if ($line =~ /^ *NAME *= *$name\s*$/)
          { $found = $TRUE;
            printf OUT $lastline;

            while ($line !~ /^ *END_OBJECT *=.*_DEFINITION/)
              { printf OUT $line;
                $line = <DD>;
              }
            printf OUT $line;
          }
        else
          { $lastline = $line; }
      }

    # Print a message if we didn't find a match:

    if (!($found))
      { printf OUT "No match found.\n"; }
  }

# Close up and we're done:

close(DD);
close(OUT);
