.\" Manual page for the PDS Label Index Generator (pdsidx)
.\"
.\" 13 July 1995, a.c.raugh
.\" 06 Dec 2005, acr: Upgrades
.\"
.TH PDSIDX L "06 Dec 2005"
.SH NAME
pdsidx \- Index table generator for PDS labels
.SH SYNOPSIS
.B pdsidx
.RB [ \-n ]
.RB [ \-r ]
.RB [ \-v ]
.RB [ \-u ]
.RB [ \-o 
.IR "<output file>" ]
.RB [ \-f
.IR "<keyword list file>" ]
.RB [ \-d
.IR "<root directory>" ]
.RB "[\| [\|"
.IR "[+|-]<keyword>/<width>" "[\|" "/default" "\|]"
.RB "\|] " ... " \|] "
.SH DESCRIPTION
.LP
.B pdsidx
searches PDS label files (identified as ending with an ".lbl" extension) and
extracts keyword values to generate an index.  The user may specify keywords
in addition to or instead of the standard keywords\; output widths and
justification (left or right) may also be specified, along with a default
value to use when the keyword is not found in a label.  All columns in the
output file are listed in the order of specification, with standard keywords
coming first\; all columns are separated by a single space.
.\"---------------------------------------------------------------------------
.SH OPTIONS
.TP
.B \-n
No standard keywords \- do not include the standard list of keywords in the 
output index
.TP
.B \-r
Descend recursively through all subdirectories and include all ".lbl" files
found
.TP
.B \-v
Include a column for VOLUME_ID in the default keyword list.  This is 
ignored if the "\-n" option is also used.
.TP
.B \-u
Remove the units from any numeric value. (See the note on units in the
.B "Keyword Specifiers"
section.)
.TP
.BI \-o " output_file"
Direct the output to the named file.  Output goes to stdout by default.
.TP
.BI \-f " keyword_list_file"
Read a list of keywords specifications from the given file.  These should
be in the same format as the command-line keyword specifications.  
Values  from this file will
be included after the standard keywords (if included) and before 
command-line keywords.
.TP
.BI \-d " root_directory"
The directory in which to root the search.  Default is the current working
directory.
.\"
.\"
.\"
.SH KEYWORD SPECIFIERS
.LP
.B pdsidx
takes an optional list of keywords, widths and literal values 
on the command line.  When
included, they are placed after the standard keywords and any others
read from the keyword_list_file in the output file.
.LP
Keyword specifiers must be in the format: [+\|-]<keyword>/<width>[/<value>],
where "keyword" is the PDS keyword to be included\; "width" is the number of
characters to allow in the output listing\; and "value" is a default value to
use if "keyword" is not found in a label file.
.LP
Note on Units:
.LP
If a '+' precedes the keyword, then the units for that field will be included,
regardless of the presence of the 
.B \-u
option. If a '-' precedes the keyword, then the units for that field will be
removed, even when the
.B \-u
option isn't given.
.LP
A negative value for "width" indicates that the field should be left-justified
in the output listing (right-justification is the default).
If "width" is omitted it is set to 10, or to the length of the default value, 
if one is supplied.
If no "value" is included, the output field is blank when a keyword is not
found in a particular label.
.LP
Top-level keywords (i.e., those not enclosed in OBJECT descriptions) are 
specified using just the keyword itself.  For keywords in objects, include 
the OBJECT type(s) as a path.  For example:
.sp
TABLE.NAME/-30
.sp
indicates that the NAME keyword from the TABLE object should be included in
the output list, with a width of 30 characters and left-justified.
.sp
TABLE.COLUMN[3].NAME
.sp
indicates that the NAME value of the third column in the (first) table should
be included, using the default width of 10 characters and right-justified. 
Objects are numbered
from 1\; if an object subscript is not included it is assumed to be 1.
.LP
For list and set values, use parentheses to extract a single value. For
example:
.sp
QUATERNION(1)
.sp
extracts the first value from the QUATERNION keyword's list value, and:
.sp
KEYWORD(1,2)
.sp
extracts the 2nd item from the 1st sublist in a 2-dimensional list, for
example, the value '2.0' from the following statement:
.sp
KEYWORD = ((1.5, 2.0, 3.7)("A", "B", "C"))
.sp
Specifying a keyword that has list or set values without specifying an index
will result in all of the values being extracted, in order, into separate
columns. This is not allowed for two-dimensional lists, but providing
a single index for a two dimensional list, e.g.:
.sp
KEYWORD(2)
.sp
will result in the expansion of the specified sublist (in this case, three
columns holding the values "A", "B", and "C".)
.LP
There are also several special identifiers used to indicate information which
might be desired in an index listing but which does not have a clear keyword
association.  These are:
.sp
.ta 5 +12
.TP
.B ^FILE_SPECIFICATION_NAME
The path and label file name, with file extension
.TP
.B ^PATH
The path from the root directory to the file directory
.TP
.B ^LABEL
The name of the label file without the ".lbl" extension
.TP
.B ^FILE
The full name of the data file, with extension but without
any path name (this is taken from the label object pointer)
.TP
.B ^OFFSET
Byte offset of the object, also from the object pointer
.TP
.B ^OBJECT
The major object type, as indicated by the FIRST object pointer found.  All
subsequent pointers are ignored.
.LP
The standard keyword specifiers are those required in all INDEX_TABLE objects:
.sp
	^FILE_SPECIFICATION_NAME/-50
.br
	PRODUCT_ID/-30
.br
	DATA_SET_ID/-40
.br
	PRODUCT_CREATION_TIME/-19
.LP
If the \-v option is used, the VOLUME_ID is inserted after the DATA_SET_ID
in the above list, with a default value of "NULL_0001", using the keyword
specifier: VOLUME_ID/-11/NULL_0001.
(No default value is provided for any of the other standard keywords, since
they are required to be present in all data labels.)
.\"
.SH FILES
.TP
.B Keyword list file
A list of keyword specifiers, one per line.  These should be in the same
format as those on the command line.  The "#" character is used to indicate
comments \- anything following it on the line is ignored.  Blank lines are
also ignored.
.\"
.SH USAGE NOTES
.LP
If a keyword is listed more than once (if it is in the default list and also
included on the command line, for example) it will be listed in the output 
more than once as well.
.LP
Values that exceed the field width given are truncated.
.LP
If a default value includes space or non-aplhanumerics, it should be 
enclosed in quotes.  Special characters will have to be escaped on the
command line.
