.\" Manual page for the 'ppodl' routine
.\"
.\" 28 November 1995, a.c.raugh.
.\" 11 Jun 1996, acr: added installation instructions
.\" 03 May 1999, acr: added "-p" switch; optional file arguments; force 
.\"                   keywords to uppercase before processing
.\" 14 Feb 2001, acr: added note that symbolic values are also forced to 
.\"                   upper case.
.\" 04 Oct 2002, acr: added "-nb" switch
.\" 04 Mar 2005, acr: updated for bug fix
.\"
.TH PPODL L "04 March 2005"
.SH NAME
ppodl \- pretty-printer for PDS ODL files (e.g., labels and catalog files)
.SH SYNOPSIS
.B ppodl
.RB "[\| " \-p " \|] [\| " \-nb " \|] "
.RB " [\| " input-file " [\| " output-file " \|] \|] "
.\"------------------
.SH DESCRIPTION
.LP
.B ppodl
takes a nasty-looking PDS ODL file (label or catalog file) and reformats it
into a style I like.
Sequential equal signs are aligned wherever possible, blank lines are inserted
before OBJECT definitions which are not already preceded by them, indentation
is made uniform and propagated down through subobjects, and keywords and
symbolic values are forced
to all upper-case.
Spacing withing
long prose fields (DESCRIPTIONs and NOTEs) is preserved relative to the new 
margin.
.LP
Optionally, the user may specify that the output lines be padded out to 80 
characters and delimited by carriage-return and linefeed characters, as 
required for PDS archive labels and catalog files. 
Also, the blank line insertion can be disabled if desired.
.LP 
Leading and trailing whitespace and whitespace surrounding the "=" are not
considered significant; whitespace in all other places is and is preserved 
as in the original file.  Lines which exceed 80 bytes after the reformatting 
are also preserved, and a list of long lines is sent to stderr on completion.
.LP
Input is from the named file, or stdin if none is given.  The formatted
output file goes to the second named file, or stdout if none.
.LP
Unless the \-p option is used, the output file will have the same carriage
control as the input file, and all trailing blanks will be trimmed from 
all label lines.
.\"------------------
.SH OPTIONS
.TP
.B \-p
Pad lines out to fixed-length of 80 bytes, including CR/LF carriage-control.
Default is to trim  all trailing whitespace from the input records and use
the same carriage control as originally found in the file.
.TP
.B \-nb
Suppresses the insertion of blank lines before and after comments and 
OBJECT definitions.
.\"------------------
.SH NOTES
.LP
.B ppodl
assumes the input label is valid and does no syntax checking.
.\"------------------
.SH INSTALLATION NOTES
.LP
.B ppodl
is contained in a single Perl script file with no additional required files.
To run it locally, the first line must be modified to contain the path to the 
local Perl interpretor.
