#!/usr/bin/perl

# sbnlblchk:  Routine to run quickly through label files and run the local
#           data label verifier on each.
#
#  Format: sbnlblchk [-e | -s | -a] [-r] label [ label [...]]
#
#            -e, -s, -a  indicates ground, spacecraft or ancillary data
#            -r          descend recursively through any subdirectories
#            label       file descriptor (may be a directory)
#
#    Note: Only "*.lbl" files are checked.
#
#  30 Apr 1996, acr: Added blank line print before callind 'sbnlc' to 
#                    provide some separation in printout.
#

# Parse command line:

$label_type = "";

if (@ARGV == 0)
  { die "Usage: sbnlblchk [-e|-s|-a] [-r] <label> [...]\n"; }

while (($arg = shift @ARGV) =~ /^-/)
  { if ($arg eq "-r")
      { $recurse = 1; }
    elsif ($arg eq "-e"  ||  $arg eq "-s"  ||  $arg eq "-a")
      { if ($label_type ne "")
          { die "Usage: sbnlblchk [-e|-s|-a] [-r] <label> [...]\n"; }
        else
          { $label_type = $arg; }
      }
    else
      { die "Usage: sbnlblchk [-e|-s|-a] [-r] <label> [...]\n"; }
  }

unshift(@ARGV,$arg);

if (@ARGV == 0)
  { die "Usage: sbnlblchk [-e|-s|-a] [-r] <label> [...]\n"; }

$label_type = "-s" if ($label_type eq "");    # set default if no type given

#------------------------------------------
# Loop through input file list, collecting the label and directory files
# into separate lists:

$fn = $dn = 0;

while ($arg = shift @ARGV)
  { if ($arg eq "."  || $arg eq "..")
      { next; }
    elsif (-d $arg)
      { $dlist[$dn] = $arg;
        $dn++;
      }
    elsif ($arg =~ /\.lbl$/)
      { $flist[$fn] = $arg;
        $fn++;
      }
  }

# Run through the label files first:

if ($fn > 0)
  { for ($i=0; $i<$fn; $i++)
      { printf "\n";
        system "sbnlc $label_type $flist[$i]"; 
        printf "\n";
      }
  }

# If "-r" was specified, descend through the directories:

if ($recurse  &&  $dn > 0)
  { for ($i=0; $i<$dn; $i++)
      { &descend($dlist[$i],$label_type); }   # This is done in a recursive 
  }                                           # subroutine.

#------------------
# Done.
#==============================================================================

sub descend

#  Recursive subroutine tfor processing subdirectories and their label files.
#
#   Arguments: $_[0] = directory (unopened)
#              $_[1] = label type flag (-e, -s or -a)
#
  { local ($dir=$_[0], $lt=$_[1]);
    local (@label_file);             # label file list
    local (@subdir);                 # subdirectory list
    local ($lf,$sd);                 # array subscripts
    local ($file,$full_name,$i);

    # Open the current directory:

    opendir(DIR,$dir)  || die "sbnlblchk: Could not open \"$dir\".\n";

    # Run through the list of files in the directory, saving the label and
    # subdirectory files into separate lists for processing:

    $lf = $sd = 0;
    foreach $file (readdir(DIR))
      { if ($file eq "."  ||  $file eq "..")
          { next; }
        $file = $dir . '/' . $file;
        if ($file =~ /\.lbl$/i)
          { $label_file[$lf] = $file;
            $lf++;
          }
        elsif (-d $file)
          { $subdir[$sd] = $file;
            $sd++;
          }
      }

    # Now process the label files:

    foreach $file (@label_file)
      { system "sbnlc $lt $file";
        printf "\n";
      }

    # Close the current directory and process the subdiretories: 

    close(DIR);

    foreach $file (@subdir)
      { &descend($file,$lt); }
  }
