/*
   TVERR.H

   Header file to define error code constants for PDSTV and the 'tverr'
   subroutine.

   02 January 2002, ACR.
*/

#ifndef TVERR
#define TVERR

/* Error codes: */

#define USAGE                    999

/* ...Label Errors... */

#define BAD_COLNUM               101
#define BAD_CONSTANT             102
#define BAD_DER_MAXMIN           103
#define BAD_END_OBJECT           104
#define BAD_REPCOUNT             105
#define BAD_SPARE_TYPE           106
#define COLUMN_MISCOUNT          107
#define CONTAINER_TOO_LONG       108
#define DBLMAX_LT_MIN            109
#define DBLVALMAX_LT_VALMIN      110
#define DERMAX_LT_DERMIN         111
#define EMPTY_CONTAINER          112
#define FIELD_TOO_LONG           113
#define FORMAT_TOO_BIG           114
#define FORMAT_TYPE_MISMATCH     115
#define INT_TYPE_CONFLICT        116
#define INV_CHAR_IN_FN           117
#define INV_FILE_RECORDS         118
#define INV_FORMAT               119
#define INV_INT_SIZE             120
#define INV_REAL_SIZE            121
#define INV_RECORD_BYTES         122
#define INV_RECORD_TYPE          123
#define INV_REP                  124
#define INV_SUBOBJECT            125
#define ITEM_BYTES_MISMATCH      126
#define MAX_TOO_LONG             127
#define MIN_TOO_LONG             128
#define MISSING_POINTER          129
#define MISSING_SCALE            130
#define MIXED_CASE_IN_FN         131
#define MULT_EXT_IN_FN           132
#define NO_EXT_IN_FN             133
#define NO_FILE_RECORDS          134
#define NO_RECORD_BYTES          135
#define NO_RECORD_TYPE           136
#define NO_REPCOUNT              137
#define NO_TABLES                138
#define OBJLBL_MISMATCH          139
#define OBSOLETE_KEYWORD         140
#define OBSOLETE_TYPE            141
#define OPEN_FAIL                142
#define PREC_GT_WIDTH            143
#define QUOTED_UNDERSCORES       144
#define ROWB_NE_RECB             145
#define SCALE_EQ_0               146
#define STARTBYTE_LT_1           147
#define STARTBYTE_GT_PAR_BYTES   148
#define STARTBYTE_GT_ROW_BYTES   149
#define STRMAX_LT_MIN            150
#define STRVALMAX_LT_VALMIN      151
#define UNEXP_END                152
#define UNEXP_EOF                153
#define UNNAMED_COLUMN           154
#define UNNAMED_CONTAINER        155
#define VALUE_TOO_LONG           156
#define WIDTH_GT_BYTES           157
#define WIDTH_GT_MAX_DATE        158
#define WIDTH_GT_MAX_TIME        159
#define WIDTH_LT_BYTES           160
#define WIDTH_LT_MIN_DATE        161
#define WIDTH_LT_MIN_TIME        162

/* ...Data (File) Errors... */

#define DATA_FILE_NOT_FOUND      201
#define FILE_SEEK_FAILED         202
#define MAX_ERRORS               203
#define OOPS_NUMBER_SIZE         204
#define TOO_FEW_TABLE_ROWS       205


/* ...Data (Field) Errors... */

#define   GREATER_THAN_MAX             0
#define   LESS_THAN_MIN                1
#define   GREATER_THAN_DMAX            2
#define   LESS_THAN_DMIN               3
#define   GREATER_THAN_VMAX            4
#define   LESS_THAN_VMIN               5
#define   INVALID_INTEGER              6
#define   INVALID_REAL                 7
#define   NONPRINT_CHAR                8
#define   LENGTH_NE_RECORD_BYTES       9
#define   NO_CR                       10
#define   E_FORMAT_MISSING_EXPONENT   11
#define   DECIMAL_NOT_ALIGNED         12
#define   INTEGER_NOT_RIGHT_JUSTIFIED 13
#define   BLANK_FIELD                 14
#define   INVALID_DATE                15
#define   INVALID_TIME                16

#define  ERRORLISTCOUNT     17

static char    *error_msg[]   = 
{ /*  0 */ "Value greater than MAXIMUM",
  /*  1 */ "Value less than MINIMUM",
  /*  2 */ "Adjusted value greater than DERIVED_MAXIMUM",
  /*  3 */ "Adjusted value less than DERIVED_MINIMUM",
  /*  4 */ "Value greater than VALID_MAXIMUM",
  /*  5 */ "Value less than VALID_MINIMUM",
  /*  6 */ "Not a valid integer",
  /*  7 */ "Not a valid real number",
  /*  8 */ "Non-printing character in CHARACTER field",
  /*  9 */ "Record length not equal to RECORD_BYTES",
  /* 10 */ "Record does not have carriage-return (\\r)",
  /* 11 */ "'E' format field does not have an exponent",
  /* 12 */ "'F' format field decimal point does not align with precision value",
  /* 13 */ "'I' format field is not right-justified",
  /* 14 */ "Blank field",
  /* 15 */ "Invalid DATE format (must be YYYY-DDD or YYYY-MM-DD)",
  /* 16 */ "Invalid TIME format (must be yyyy-mm-ddThh[:mm:ss.s...] or yyyy-dddThh[:mm:ss.s...])"
 };


/* Subroutine declaration: */

int tverr(int ecode,...);

#endif
