.\" Manual page for the 'vc_labels' routine
.\"
.\" 27 February 2008, A.C.Raugh.
.\" 03 Mar 2008, ACR: added --sbn-ignore and --exclude options
.\"
.TH VC_LABELS L "03 March 2008"
.SH NAME
vc_labels \- check a PDS volume structure to make sure all files have
labels and all file referenced in label data pointers exist.
.SH SYNOPSIS
.B vc_labels
.RB "[\|" \-o 
.IR output "\|]"
.RB " [\|" \-\-sbn\-ignore "\|] [\|" \-\-exclude
.IR pattern "\|]  root_dir"
.\"------------------
.SH DESCRIPTION
.LP
.B vc_labels
reads through a PDS volume structure checking that all files referenced in 
label data pointers exist, and that all non-ODL files are referenced by
at least one label.
A warning is printed when a file is referenced by more than one label,
since this is usually an accident.  
(It's not a good idea in data directories, but frequently useful in 
other directories.)
.LP
Catalog and format files are ignored.  These and label files are identified
by their extensions (".cat", ".fmt" and ".lbl", respectively).  This 
program does not attempt to check case or validity of files names or
PDS syntax.
The user can specify additional files and directories to be ignored 
via the 
.I \-\-exclude
options, which takes as an argument a regular expression to match against
file specifications (path and filename).
This option may be repeated as necessary.
.\"------------------
.SH OPTIONS
.TP
.BI \-o " output"
Direct output to the named file.  Default is to direct output to stdout.
.TP
.BI \-\-exclude " pattern" " or \-x" " pattern"
Exclude files and directories matching the given regular expression.
Any match anywhere in the path or file name will cause the file to be 
excluded.
.TP
.B \-\-sbn\-ignore
Adds the list of SBN archive RAID support files and directories to the 
exclusion list.
.\"------------------
.SH USAGE NOTES
.LP
Because PDS requires that all file and directory names be case-insensitive,
all file names - whether from the file system or the label pointers -
are forced to lower case prior
to comparison to simplify the program logic.
Consequently, when checking directories with upper case filenames, any error
messages will likely show the file name in lower case.
The case difference is NOT the cause of the discrepancy.
.LP
Unless something is specifically flagged as a "WARNING", it is a violation
of PDS Standards.  Warnings are generated for violations of conventions
that are strongly recommend, like fixed-length records less than 80 bytes
in labels and catalog files, but these are not strictly required.
.LP
Note that the EXTRAS/ directory, when it appears, is not required to meet
any PDS Standards except for the presence of a valid EXTRINFO.TXT file.
This routine will check it anyway, though.  If it is generating a lot
of annyoing messages, use the 
.B \-\-exclude 
option ("\-\-exclude EXTRAS" or "\-\-exclude extras", depending on 
the actual case) to ignore it.
.LP
If a file is flagged as having no label, but you can clearly see a label
file in the same directory, check the pointer.  First, look for the 
obvious typos, but also look for the wrong king of object.  For example,
a common "good guess" is to use a TEXT object to label an AAREADME.TXT
file.  But according to the pointer resolution rules, anything referenced
by a ^TEXT pointer 
.I must
be in the DOCUMENT/ directory.  This is because the TEXT object is not
a data object and is resolved using the 
.I descriptive
pointer rules, not the 
.I "data object"
pointer rules.
So, in this example, the TEXT object in the label needs to be replaced 
with a DOCUMENT (or TEXT_DOCUMENT, if you prefer) object, with the
appropriate type of pointer.
