.\" Manual page for the 'vc_refint' routine
.\"
.\" 05 March 2008, A.C.Raugh.
.\" 07 Mar 2008, ACR: Additional options
.\"
.TH VC_REFINT L "07 March 2008"
.SH NAME
vc_refint \- check a PDS volume structure for referential integrity.
.SH SYNOPSIS
.B vc_refint
.RB "[\|" \-u "\|]"
.RB "[\|" \-s "\|]"
.RB "[\|" \-h "\|]"
.RB "[\|" \-o 
.IR output "\|]"
.RB "[\|" \-\-sbn\-ignore "\|]"
.RB "[\|" \-\-ignored\-defined "\|]"
.RB "[\|" \-\-allrefs
.IR allrefs_file "\|]"
.RB "[\|" \-\-pdsdd
.IR pdsdd_file "\|]"
.RB "[\|" \-\-exclude
.IR pattern "\|]  root_dir"
.\"------------------
.SH DESCRIPTION
.LP
.B vc_refint
reads through all the files in a PDS volume structure to ensure that all 
catalog database key values used are actually defined in a file included
in the catalog/ directory of the volume.
Undefined values are flagged as they are encountered, and a summary is
provided of all undefined values at the end of the listing.
.LP
Options allow the user to direct output to a named file, exclude files
and directories based on regular expression patterns, and to suppress
the individual file error messages and just display the summary.
.LP
The user may also specify that key values already defined in the data 
dictionary may be ignored. 
In order for this to be possible, though, this program needs access to 
a current copy of the 
.I pdsdd.full
and
.I allrefs.out
files, both available from the main PDS website. 
Default locations for these files are hard-coded into the code, but
alternate locations may be specified using the corresponding options.
.\"------------------
.SH OPTIONS
.TP
.BR \-h " or " \-\-help " or " \-?
Displays an options summary
.TP
.B \-u
Volume file and directory names are uppercase.  The default is to 
look for lowercase names.
.TP
.BR \-s " or " \-\-summary\-only
Display only the summary listing of the unmatched key values by category.
This option suppresses flagging of each undefined value as it is encountered.
It will also display a total count of non-fatal syntax errors encountered.
.TP
.BI \-o " output"
Direct output to the named file.  Default is to direct output to stdout.
.TP
.BI \-\-exclude " pattern" " or \-x " " pattern"
Exclude files and directories matching the given regular expression.
Any match anywhere in the path or file name will cause the file to be 
excluded.
.TP
.B \-\-sbn\-ignore
Adds the list of SBN archive RAID support files and directories to the 
exclusion list.
.TP
.B \-\-ignore\-defined
Do not flag database key values that already exist in standard value 
lists in the pdsdd.full file, or the allrefs.out file in the case of
REFERENCE_KEY_ID values.
.TP
.BI \-\-allrefs " allrefs_file"
Specify an alternate name and location for the allrefs.out file.  
The default name and location are hard-coded into the script and should be
changed on installation to an appropriate value for the site.
This option is only meaningful with the
.B \-\-ignore\-defined
option.
.TP
.BI \-\-pdsdd " pdsdd_file"
Specify an alternate name and location for the pdsdd.full file.
The default name and location are hard-coded into the script and should be
changed on installation to an appropriate value for the site.
This option is only meaningful with the
.B \-\-ignore\-defined
option.
.\"------------------
.SH USAGE NOTES
.LP
The routine checks the beginning of every file encountered to see if it 
contains ODL.  If the string "PDS_VERSION_ID =" is found in the first 
300 bytes of the file, it is assumed to contain a label (possibly attached)
or catalog file.  
Be aware that old PDS files and files which begin with extensive 
comments will fail this test.
.LP
This routine also assumes the ODL it encounters is syntactically valid.
If that is not true, all bets are off.
.LP
Note that as of this writing Appendix B of the PDS Standards Reference
requires a complete catalog set in any archival delivery, regardless of
whether or not previous versions of catalog files exist or have been
modified.
.LP
The URL containing links to the latest pdsdd.full and allrefs.out file
is on the left menu bar of this page:
.LP
http://pds.nasa.gov/tools/data_dictionary_lookup.cfm
.LP
The pdsdd.full and allrefs.out files are updated simultaneously.
Users may subscribe to receive notification of new releases of these files
via the PDS subscription service, available from the Data Services section
of the main PDS web site.
